from thinc.typedefs cimport atom_t

from .stateclass cimport StateClass
from .arc_eager cimport TransitionSystem
from ..vocab cimport Vocab
from ..tokens.doc cimport Doc
from ..structs cimport TokenC
from ._state cimport StateC


cdef class Parser:
    cdef readonly Vocab vocab
    cdef public object model
    cdef readonly TransitionSystem moves
    cdef readonly object cfg
    cdef public object _multitasks

    cdef void _parseC(self, StateC* state, 
            const float* feat_weights, const float* bias,
            const float* hW, const float* hb,
            int nr_class, int nr_hidden, int nr_feat, int nr_piece) nogil



# encoding: utf8
from __future__ import unicode_literals

# Source: collected from different resource on internet

STOP_WORDS = set("""
ثھی
 خو
  گی
   اپٌے
    گئے
     ثہت
      طرف
       ہوبری
        پبئے
         اپٌب
          دوضری
           گیب
            کت
             گب
              ثھی
               ضے
                ہر
پر
اش
 دی
 گے
لگیں
ہے
ثعذ
 ضکتے
  تھی
   اى
    دیب
     لئے
      والے
       یہ
        ثدبئے
         ضکتی
          تھب
           اًذر
            رریعے
             لگی
              ہوبرا
               ہوًے
                ثبہر
                 ضکتب
                  ًہیں
                   تو
                    اور
رہب
 لگے
  ہوضکتب
   ہوں
    کب
     ہوبرے
      توبم
       کیب
        ایطے
         رہی
          هگر
           ہوضکتی
            ہیں
             کریں
              ہو
               تک
                کی
                 ایک
                  رہے
                   هیں
 ہوضکتے
  کیطے
   ہوًب
    تت
     کہ
      ہوا
       آئے
        ضبت
         تھے
          کیوں
           ہو
            تب
             کے
              پھر
               ثغیر
                خبر
                ہے
                 رکھ
                  کی
                   طب
                    کوئی
                     رریعے
ثبرے
 خب
  اضطرذ
   ثلکہ
    خجکہ
     رکھ
      تب
       کی
        طرف
         ثراں
          خبر
            رریعہ
 اضکب
  ثٌذ
   خص
 کی
  لئے
 توہیں
دوضرے
 کررہی
  اضکی
   ثیچ
    خوکہ
     رکھتی
      کیوًکہ
       دوًوں
        کر
         رہے
          خبر
           ہی
            ثرآں
             اضکے
              پچھلا
               خیطب
                رکھتے
                 کے
                  ثعذ
                   تو
                    ہی
                     دورى
کر
 یہبں
 آش
  تھوڑا
  چکے
  زکویہ
  دوضروں
  ضکب
  اوًچب
  ثٌب
  پل
  تھوڑی
  چلا
  خبهوظ
  دیتب
  ضکٌب
  اخبزت
  اوًچبئی
  ثٌبرہب
پوچھب
تھوڑے
چلو
ختن
دیتی
ضکی
اچھب
اوًچی
ثٌبرہی
پوچھتب
تیي
چلیں
در
دیتے
ضکے
اچھی
اوًچے
ثٌبرہے
پوچھتی
خبًب
چلے
درخبت
دیر
ضلطلہ
اچھے
اٹھبًب
ثٌبًب
پوچھتے
خبًتب
چھوٹب
درخہ
دیکھٌب
ضوچ
اختتبم
اہن
ثٌذ
پوچھٌب
خبًتی
چھوٹوں
درخے
دیکھو
ضوچب
ادھر
آئی
ثٌذکرًب
پوچھو
خبًتے
چھوٹی
درزقیقت
دیکھی
ضوچتب
ارد
آئے
ثٌذکرو
پوچھوں
خبًٌب
چھوٹے
درضت
دیکھیں
ضوچتی
اردگرد
آج
ثٌذی
پوچھیں
خططرذ
چھہ
دش
دیٌب
ضوچتے
ارکبى
آخر
ثڑا
پورا
خگہ
چیسیں
دفعہ
دے
ضوچٌب
اضتعوبل
آخر
پہلا
خگہوں
زبصل
دکھبئیں
راضتوں
ضوچو
اضتعوبلات
آدهی
ثڑی
پہلی
خگہیں
زبضر
دکھبتب
راضتہ
ضوچی
اغیب
آًب
ثڑے
پہلےضی
خلذی
زبل
دکھبتی
راضتے
ضوچیں
اطراف
آٹھ
ثھر
خٌبة
زبل
دکھبتے
رکي
ضیذھب
افراد
آیب
ثھرا
پہلے
خواى
زبلات
دکھبًب
رکھب
ضیذھی
اکثر
ثب
ہوا
پیع
خوًہی
زبلیہ
دکھبو
رکھی
ضیذھے
اکٹھب
ثھرپور
تبزٍ
خیطبکہ
زصوں
رکھے
ضیکٌڈ
اکٹھی
ثبری
ثہتر
تر
چبر
زصہ
دلچطپ
زیبدٍ
غبیذ
اکٹھے
ثبلا
ثہتری
ترتیت
چبہب
زصے
دلچطپی
ضبت
غخص
اکیلا
ثبلترتیت
ثہتریي
تریي
چبہٌب
زقبئق
دلچطپیبں
ضبدٍ
غذ
اکیلی
ثرش
پبش
تعذاد
چبہے
زقیتیں
هٌبضت
ضبرا
غروع
اکیلے
ثغیر
پبًب
چکب
زقیقت
دو
ضبرے
غروعبت
اگرچہ
ثلٌذ
پبًچ
تن
چکی
زکن
دور
ضبل
غے
الگ
پراًب
تٌہب
چکیں
دوضرا
ضبلوں
صبف
صسیر
قجیلہ
کوًطے
لازهی
هطئلے
ًیب
طریق
کرتی
کہتے
صفر
قطن
کھولا
لگتب
هطبئل
وار
طریقوں
کرتے
کہٌب
صورت
کئی
کھولٌب
لگتی
هطتعول
وار
طریقہ
کرتے
ہو
کہٌب
صورتسبل
کئے
کھولو
لگتے
هػتول
ٹھیک
طریقے
کرًب
کہو
صورتوں
کبفی
هطلق
ڈھوًڈا
طور
کرو
کہوں
صورتیں
کبم
کھولیں
لگی
هعلوم
ڈھوًڈلیب
طورپر
کریں
کہی
ضرور
کجھی
کھولے
لگے
هکول
ڈھوًڈًب
ظبہر
کرے
کہیں
ضرورت
کرا
کہب
لوجب
هلا
ڈھوًڈو
عذد
کل
کہیں
کرتب
کہتب
لوجی
هوکي
ڈھوًڈی
عظین
کن
کہے
ضروری
کرتبہوں
کہتی
لوجے
هوکٌبت
ڈھوًڈیں
علاقوں
کوتر
کیے
لوسبت
هوکٌہ
ہن
لے
ًبپطٌذ
ہورہے
علاقہ
کورا
کے
رریعے
لوسہ
هڑا
ہوئی
هتعلق
ًبگسیر
ہوگئی
علاقے
کوروں
گئی
لو
هڑًب
ہوئے
هسترم
ًطجت
ہو
گئے
علاوٍ
کورٍ
گرد
لوگ
هڑے
ہوتی
هسترهہ
ًقطہ
ہوگیب
کورے
گروپ
لوگوں
هہرثبى
ہوتے
هسطوش
ًکبلٌب
ہوًی
عووهی
کوطي
گروٍ
لڑکپي
هیرا
ہوچکب
هختلف
ًکتہ
ہی
فرد
کوى
گروہوں
لی
هیری
ہوچکی
هسیذ
فی
کوًطب
گٌتی
لیب
هیرے
ہوچکے
هطئلہ
ًوخواى
یقیٌی
قجل
کوًطی
لیٌب
ًئی
ہورہب
لیں
ًئے
ہورہی
ثبعث
ضت
""".split())



# coding: utf-8
from __future__ import unicode_literals

from ..tokens import Doc
from ..attrs import ORTH, POS, HEAD, DEP
from ..compat import path2str

import pytest
import numpy
import tempfile
import shutil
import contextlib
import msgpack
from pathlib import Path


MODELS = {}


def load_test_model(model):
    """Load a model if it's installed as a package, otherwise skip."""
    if model not in MODELS:
        module = pytest.importorskip(model)
        MODELS[model] = module.load()
    return MODELS[model]


@contextlib.contextmanager
def make_tempfile(mode='r'):
    f = tempfile.TemporaryFile(mode=mode)
    yield f
    f.close()


@contextlib.contextmanager
def make_tempdir():
    d = Path(tempfile.mkdtemp())
    yield d
    shutil.rmtree(path2str(d))


def get_doc(vocab, words=[], pos=None, heads=None, deps=None, tags=None, ents=None):
    """Create Doc object from given vocab, words and annotations."""
    pos = pos or [''] * len(words)
    tags = tags or [''] * len(words)
    heads = heads or [0] * len(words)
    deps = deps or [''] * len(words)
    for value in (deps+tags+pos):
        vocab.strings.add(value)

    doc = Doc(vocab, words=words)
    attrs = doc.to_array([POS, HEAD, DEP])
    for i, (p, head, dep) in enumerate(zip(pos, heads, deps)):
        attrs[i, 0] = doc.vocab.strings[p]
        attrs[i, 1] = head
        attrs[i, 2] = doc.vocab.strings[dep]
    doc.from_array([POS, HEAD, DEP], attrs)
    if ents:
        doc.ents = [(ent_id, doc.vocab.strings[label], start, end) for ent_id, label, start, end in ents]
    if tags:
        for token in doc:
            token.tag_ = tags[token.i]
    return doc


def apply_transition_sequence(parser, doc, sequence):
    """Perform a series of pre-specified transitions, to put the parser in a
    desired state."""
    for action_name in sequence:
        if '-' in action_name:
            move, label = action_name.split('-')
            parser.add_label(label)
    with parser.step_through(doc) as stepwise:
        for transition in sequence:
            stepwise.transition(transition)


def add_vecs_to_vocab(vocab, vectors):
    """Add list of vector tuples to given vocab. All vectors need to have the
    same length. Format: [("text", [1, 2, 3])]"""
    length = len(vectors[0][1])
    vocab.reset_vectors(width=length)
    for word, vec in vectors:
        vocab.set_vector(word, vector=vec)
    return vocab


def get_cosine(vec1, vec2):
    """Get cosine for two given vectors"""
    return numpy.dot(vec1, vec2) / (numpy.linalg.norm(vec1) * numpy.linalg.norm(vec2))


def assert_docs_equal(doc1, doc2):
    """Compare two Doc objects and assert that they're equal. Tests for tokens,
    tags, dependencies and entities."""
    assert [ t.orth for t in doc1 ] == [ t.orth for t in doc2 ]

    assert [ t.pos for t in doc1 ] == [ t.pos for t in doc2 ]
    assert [ t.tag for t in doc1 ] == [ t.tag for t in doc2 ]

    assert [ t.head.i for t in doc1 ] == [ t.head.i for t in doc2 ]
    assert [ t.dep for t in doc1 ] == [ t.dep for t in doc2 ]
    if doc1.is_parsed and doc2.is_parsed:
        assert [ s for s in doc1.sents ] == [ s for s in doc2.sents ]

    assert [ t.ent_type for t in doc1 ] == [ t.ent_type for t in doc2 ]
    assert [ t.ent_iob for t in doc1 ] == [ t.ent_iob for t in doc2 ]
    assert [ ent for ent in doc1.ents ] == [ ent for ent in doc2.ents ]


def assert_packed_msg_equal(b1, b2):
    """Assert that two packed msgpack messages are equal."""
    msg1 = msgpack.loads(b1, encoding='utf8')
    msg2 = msgpack.loads(b2, encoding='utf8')
    assert sorted(msg1.keys()) == sorted(msg2.keys())
    for (k1, v1), (k2, v2) in zip(sorted(msg1.items()), sorted(msg2.items())):
        assert k1 == k2
        assert v1 == v2



# coding: utf-8
from __future__ import unicode_literals

from ...matcher import Matcher

import pytest


@pytest.mark.models('en')
def test_issue429(EN):
    def merge_phrases(matcher, doc, i, matches):
        if i != len(matches) - 1:
            return None
        spans = [(ent_id, ent_id, doc[start:end]) for ent_id, start, end in matches]
        for ent_id, label, span in spans:
            span.merge(
                tag=('NNP' if label else span.root.tag_),
                lemma=span.text,
                label='PERSON')

    doc = EN('a')
    matcher = Matcher(EN.vocab)
    matcher.add('TEST', merge_phrases, [{'ORTH': 'a'}])
    doc = EN.make_doc('a b c')
    EN.tagger(doc)
    matcher(doc)
    EN.entity(doc)



# coding: utf8
# cython: infer_types=True
# cython: bounds_check=False
# cython: profile=True
from __future__ import unicode_literals

from libc.string cimport memcpy, memset

from .doc cimport Doc, set_children_from_heads, token_by_start, token_by_end
from .span cimport Span
from .token cimport Token
from ..lexeme cimport Lexeme, EMPTY_LEXEME
from ..structs cimport LexemeC, TokenC
from ..attrs cimport TAG
from ..attrs import intify_attrs
from ..util import SimpleFrozenDict


cdef class Retokenizer:
    """Helper class for doc.retokenize() context manager."""
    cdef Doc doc
    cdef list merges
    cdef list splits
    def __init__(self, doc):
        self.doc = doc
        self.merges = []
        self.splits = []

    def merge(self, Span span, attrs=SimpleFrozenDict()):
        """Mark a span for merging. The attrs will be applied to the resulting
        token.
        """
        attrs = intify_attrs(attrs, strings_map=self.doc.vocab.strings)
        self.merges.append((span.start_char, span.end_char, attrs))

    def split(self, Token token, orths, attrs=SimpleFrozenDict()):
        """Mark a Token for splitting, into the specified orths. The attrs
        will be applied to each subtoken.
        """
        attrs = intify_attrs(attrs, strings_map=self.doc.vocab.strings)
        self.splits.append((token.start_char, orths, attrs))

    def __enter__(self):
        self.merges = []
        self.splits = []
        return self

    def __exit__(self, *args):
        # Do the actual merging here
        for start_char, end_char, attrs in self.merges:
            start = token_by_start(self.doc.c, self.doc.length, start_char)
            end = token_by_end(self.doc.c, self.doc.length, end_char)
            _merge(self.doc, start, end+1, attrs)
        for start_char, orths, attrs in self.splits:
            raise NotImplementedError


def _merge(Doc doc, int start, int end, attributes):
    """Retokenize the document, such that the span at
    `doc.text[start_idx : end_idx]` is merged into a single token. If
    `start_idx` and `end_idx `do not mark start and end token boundaries,
    the document remains unchanged.

    start_idx (int): Character index of the start of the slice to merge.
    end_idx (int): Character index after the end of the slice to merge.
    **attributes: Attributes to assign to the merged token. By default,
        attributes are inherited from the syntactic root of the span.
    RETURNS (Token): The newly merged token, or `None` if the start and end
        indices did not fall at token boundaries.
    """
    cdef Span span = doc[start:end]
    cdef int start_char = span.start_char
    cdef int end_char = span.end_char
    # Get LexemeC for newly merged token
    new_orth = ''.join([t.text_with_ws for t in span])
    if span[-1].whitespace_:
        new_orth = new_orth[:-len(span[-1].whitespace_)]
    cdef const LexemeC* lex = doc.vocab.get(doc.mem, new_orth)
    # House the new merged token where it starts
    cdef TokenC* token = &doc.c[start]
    token.spacy = doc.c[end-1].spacy
    for attr_name, attr_value in attributes.items():
        if attr_name == TAG:
            doc.vocab.morphology.assign_tag(token, attr_value)
        else:
            Token.set_struct_attr(token, attr_name, attr_value)
    # Make sure ent_iob remains consistent
    if doc.c[end].ent_iob == 1 and token.ent_iob in (0, 2):
        if token.ent_type == doc.c[end].ent_type:
            token.ent_iob = 3
        else:
            # If they're not the same entity type, let them be two entities
            doc.c[end].ent_iob = 3
    # Begin by setting all the head indices to absolute token positions
    # This is easier to work with for now than the offsets
    # Before thinking of something simpler, beware the case where a
    # dependency bridges over the entity. Here the alignment of the
    # tokens changes.
    span_root = span.root.i
    token.dep = span.root.dep
    # We update token.lex after keeping span root and dep, since
    # setting token.lex will change span.start and span.end properties
    # as it modifies the character offsets in the doc
    token.lex = lex
    for i in range(doc.length):
        doc.c[i].head += i
    # Set the head of the merged token, and its dep relation, from the Span
    token.head = doc.c[span_root].head
    # Adjust deps before shrinking tokens
    # Tokens which point into the merged token should now point to it
    # Subtract the offset from all tokens which point to >= end
    offset = (end - start) - 1
    for i in range(doc.length):
        head_idx = doc.c[i].head
        if start <= head_idx < end:
            doc.c[i].head = start
        elif head_idx >= end:
            doc.c[i].head -= offset
    # Now compress the token array
    for i in range(end, doc.length):
        doc.c[i - offset] = doc.c[i]
    for i in range(doc.length - offset, doc.length):
        memset(&doc.c[i], 0, sizeof(TokenC))
        doc.c[i].lex = &EMPTY_LEXEME
    doc.length -= offset
    for i in range(doc.length):
        # ...And, set heads back to a relative position
        doc.c[i].head -= i
    # Set the left/right children, left/right edges
    set_children_from_heads(doc.c, doc.length)
    # Clear the cached Python objects
    # Return the merged Python object
    return doc[start]



# coding: utf8
from __future__ import unicode_literals
ADVERBS = set("""
 άβλαβα άβολα άβουλα άγαν άγαρμπα άγγιχτα άγνωμα άγρια άγρυπνα άδηλα άδικα
 άδοξα άθελα άθλια άκαιρα άκακα άκαμπτα άκαρδα άκαρπα άκεφα άκομψα άκοπα άκοσμα
 άκρως άκυρα άλαλα άλιωτα άλλοθεν άλλοτε άλλως άλλωστε άλογα άλυπα άμεμπτα
 άμετρα άμοιαστα άμορφα άνανδρα άναντρα άναρθρα άναρχα άναυλα άνετα άνισα άνομα
 άνοστα άντικρυς άνω άνω κάτω άνωθεν άξαντα άξαφνα άξεστα άξια άοκνα άοπλα
 άουτ άπαγε άπαξ άπατα άπειρα άπιστα άπλαστα άπλετα άπληστα άπονα άπρακτα
 άπρεπα άπροικα άπταιστα άπω άρδην άριστα άρρηκτα άρρυθμα άρτι άρτια άσβηστα
 άσελγα άσεμνα άσκεπα άσκεπα άσκημα άσκοπα άσμιχτα άσπαστα άσπλαγχνα άσπλαχνα
 άστοργα άστοχα άστρωτα άσφαλτα άσφαλτα άσφιχτα άσχετα άσχημα άσωστα άσωτα
 άταχτα άτεγκτα άτεχνα άτιμα άτολμα άτονα άτρωτα άτσαλα άτυπα άφευκτα άφθαστα
 άφοβα άφταστα άφωνα άφωτα άχαρα άχολα άχρηστα άχροα άχρονα άχρωμα άψαλτα
 άψε σβήσε άψητα άψυχα έγγιστα έγκαιρα έγκυρα έκδηλα έκνομα έκπαλαι έκτοτε
 έμμετρα έμπρακτα έμπροσθεν έμφυτα έναντι έναρθρα ένδοθεν ένδον ένδοξα ένθα
 ένθερμα έννομα έντεχνα έντεχνα έντιμα έντονα έξαλλα έξαφνα έξοχα έξυπνα έξω
 έξωθι έπειτα έργω έρρινα έρρυθμα έσω έσωθεν έτι έτοιμα έτσ' έτσι ήδη ήκιστα
 ήπια ήρεμα ήσυχα ίδια ίσα ίσια ίσως α προπό α τέμπο αέναα αέρινα αήθως αήττητα
 αίφνης αβάδιστα αβάντι αβάσιμα αβάσταχτα αβέβαια αβέρτα αβίαστα αβαλσάμωτα
 αβασάνιστα αβδηριτικώς αβεβαίως αβιάστως αβλαβώς αβοήθητα αβοηθήτως αβουλήτως
 αβράδιαστα αβροδίαιτα αβροδιαίτως αβρόμιστα αβρώς αγάλι αγέλαστα αγέρωχα αγαθά
 αγαθοποιά αγαθοπρεπής αγαθώς αγανά αγαπημένα αγγειακά αγγειοδιασταλτικά
 αγγειοσυσταλτικά αγγειοχειρουργικά αγγελικά αγγελοειδώς αγγλικά αγγλιστί
 αγγλοσαξωνικά αγελαδινά αγεληδόν αγενώς αγερώχως αγιάτρευτα αγιοδημητριάτικα
 αγκαλιά αγκαλιαστά αγνά αγνάντι αγνάντια αγνωμόνως αγορανομικά αγρίως αγριωπά
 αγρύπνως αγχολυτικά αγχωμένα αγχωτικά αγωνιστικά αγόγγυστα αδάκρυτα αδάμαστα
 αδέκαστα αδέξια αδέσμευτα αδήλως αδίκως αδίστακτα αδίσταχτα αδαμάστως
 αδαπάνως αδασμολογήτως αδαώς αδείλιαστα αδείπνητα αδελεάστως αδελφικά
 αδεξίως αδερφικά αδερφικάτα αδεσμεύτως αδευτέρωτα αδιάκοπα αδιάκριτα
 αδιάλλακτα αδιάλυτα αδιάνθιστα αδιάνθιστα αδιάρρηκτα αδιάσειστα αδιάσπαστα
 αδιάφορα αδιάψευστα αδιαίρετα αδιαβατικά αδιαιρέτως αδιακήρυκτα αδιακρίβωτα
 αδιακρίτως αδιακόπως αδιαλείπτως αδιαλεύκαντα αδιαλλάκτως αδιαμοίραστα
 αδιαμφισβήτητα αδιαμφισβητήτως αδιανοήτως αδιαπέραστα αδιαρρήκτως αδιασάφητα
 αδιασείστως αδιασπάστως αδιατάρακτα αδιατάραχτα αδιαταράκτως αδιαφήμιστα
 αδιαφημίστως αδιαφθόρως αδιαφιλονίκητα αδιαφιλονικήτως αδιαφόρετα αδιαφόρως
 αδιαχωρίστως αδιαχώρητα αδιαχώριστα αδιαψεύστως αδιδάκτως αδιερευνήτως
 αδιευκρινίστως αδικαίωτα αδικαιολογήτως αδικαιολόγητα αδιοικήτως αδιοράτως
 αδιορθώτως αδιστάκτως αδιόρατα αδιόρθωτα αδογμάτιστα αδογματίστως αδοκήτως
 αδολίευτα αδολιεύτως αδούλωτα αδρά αδρανώς αδρομίσθως αδρομερώς αδρώς
 αδυσώπητα αδωροδοκήτως αδόκητα αδόλως αδόξως αδύναμα αεί αείποτε αενάως
 αεροπορικά αεροπορικώς αεροστεγώς αζημίωτα αζημιώτως αζητήτως αηδιαστικά
 αηδώς αθέλητα αθέμιτα αθανάτως αθελήτως αθεμίτως αθεμελίωτα αθεράπευτα
 αθεωρήτως αθεϊστικά αθεώρητα αθηλύκωτα αθλίως αθορυβήτως αθορύβως αθραύστως
 αθροιστικώς αθρόα αθρόως αθυμιάτιστα αθυροστόμως αθυρόστομα αθόρυβα αθύμως
 αθώως αιδημόνως αιματηρά αιματολογικά αιμοβόρικα αινετά αινιγματικά αιολικά
 αισίως αισθαντικά αισθαντικώς αισθηματικά αισθηματικώς αισθησιακά
 αισθησιοκρατικά αισθητά αισθητηριακά αισθητικά αισθητικώς αισθητώς αισιοδόξως
 αισχρά αισχροκερδώς αισχρολογικά αισχρολογικώς αισχρώς αισχυντηλά αιτιακά
 αιτιοκρατικά αιτιολογικά αιτιωδώς αιφνίδια αιφνιδίως αιφνιδιαστικά
 αιχμηρά αιχμηρώς αιωνίως αιώνια ακάθεκτα ακάκως ακάματα ακάμπτως ακάρπως
 ακήρυκτα ακήρυχτα ακίνδυνα ακαίρως ακαδημαϊκά ακαδημαϊκώς ακαθάρτως ακαθέκτως
 ακαθόριστα ακαθόριστα ακακολόγητα ακαλαίσθητα ακαλαισθήτως ακαλλωπίστως
 ακαμάτως ακανονίστως ακανόνιστα ακαπέλωτα ακαριαία ακαριαίως ακατάβλητα
 ακατάβρεχτα ακατάδεκτα ακατάδεχτα ακατάληπτα ακατάλληλα ακατάλυτα ακατάπαυστα
 ακατάρτιστα ακατάρτιστα ακατάστατα ακατάσχετα ακατέβατα ακατέργαστα
 ακαταγωνίστως ακαταδέκτως ακαταλήπτως ακαταλαβίστικα ακαταλλήλως ακαταλογίστως
 ακαταλόγιστα ακαταλύτως ακαταμάχητα ακαταμαχήτως ακατανίκητα ακατανικήτως
 ακατανόητα ακαταπαύστως ακαταπαύτως ακαταπονήτως ακαταπόνητα ακαταρτίστως
 ακαταστάλακτα ακαταστάλαχτα ακαταστάτως ακατασχέτως ακατατοπίστως ακατατόπιστα
 ακατεργάστως ακατηγορήτως ακατονομάστως ακατονόμαστα ακαυτηρίαστα
 ακεραίως ακηδεμονεύτως ακηδεμόνευτα ακηδώς ακηρύκτως ακιβδήλως ακιδωτά
 ακινδύνως ακλήρως ακλήτως ακλίτως ακλαύτως ακλείδωτα ακλεώς ακλητί ακλονήτως
 ακλυδώνιστα ακλόνητα ακμαία ακμαίως ακοίταχτα ακοινωνήτως ακοινώνητα ακολάστως
 ακομμάτιαστα ακορέστως ακορόιδευτα ακοσκίνιστα ακοσμήτως ακοστολόγητα
 ακουσίως ακουστά ακουτσομπόλευτα ακούραστα ακούσια ακράδαντα ακράτητα ακράτως
 ακραία ακραδάντως ακραιφνώς ακρατήτως ακρατώς ακριβά ακριβοδίκαια
 ακριβούτσικα ακριβότερα ακριβώς ακρινά ακροβολιστί ακροθιγώς ακροποδητί
 ακτινολογικώς ακτινωτά ακυβέρνητα ακυβερνήτως ακυκλοφόρητα ακυμάντως
 ακωμωδήτως ακόλαστα ακόλουθα ακόμα ακόμη ακόμψως ακόπως ακόρδωτα ακόρεστα
 ακύμαντα ακύρως αλ ντέντε αλά καρτ αλάδωτα αλάθητα αλάλητα αλάλως αλάνθαστα
 αλάργα αλάργο αλέ-ρετούρ αλέστα αλήτικα αλίχνιστα αλαζονικώς αλαθήτως αλαλήτως
 αλαμπρατσέτα αλανθάστως αλαργινά αλαφιασμένα αλαφρά αλβανιστί αλγεινά αλγεινώς
 αλεξανδρινά αλερετούρ αληθινά αληθινώς αληθοφανώς αληθώς αλησμονήτως
 αλητικώς αλκίμως αλλέως αλλήθωρα αλλαχού αλλαχόθεν αλλεπάλληλα αλλεπαλλήλως
 αλληλέγγυα αλληλένδετα αλληλενδέτως αλληλοδιάδοχα αλληλοδιαδόχως αλληλοπαθώς
 αλληλουχικώς αλλιώς αλλιώτικα αλλοιώς αλλοκότως αλλοπαθητικά αλλοπροσάλλως
 αλλοφρόνως αλλοχωριανά αλλού αλλόκοτα αλλόφρονα αλματωδώς αλμυρά αλογάριαστα
 αλογόκριτα αλτρουιστικά αλτρουιστικώς αλυγίστως αλυπήτως αλυσιδωτά αλυσιτελώς
 αλυτρωτικά αλφάδι αλφαβητικά αλφαβητικώς αλφαδιασμένα αλωβήτως αλόγιαστα
 αλόγως αλύγιστα αλύπητα αλύπως αλύτως αλώβητα αμάθητα αμάκα αμάλαγα αμάλαχτα
 αμάρτυρα αμάσητα αμάχητα αμάχως αμέθοδα αμέμπτως αμέριμνα αμέριστα αμέρωτα
 αμέτρητα αμέτρως αμήνυτα αμίαντα αμίλητα αμαγείρευτα αμαθώς αμαλάκτως
 αμαρτωλά αμαστίγωτα αμαυρά αμαυρώς αμαχήτως αμαχητί αμείλικτα αμείλιχτα
 αμεθόδευτα αμεθόδως αμειλίκτως αμειώτως αμελετήτως αμελητί αμελλητί αμελώς
 αμερίστως αμερικάνικα αμερικανικά αμερολήπτως αμερόληπτα αμεσίτευτα αμετάβατα
 αμετάδοτα αμετάθετα αμετάκλητα αμετάπειστα αμετάτρεπτα αμεταβάτως αμεταβλήτως
 αμεταθέτως αμετακίνητα αμετακινήτως αμετακλήτως αμεταλλάκτως αμεταμέλητα
 αμετανοήτως αμετανόητα αμεταπείστως αμεταποίητα αμεταποιήτως αμετατρέπτως
 αμετροεπώς αμηνυτί αμηνύτως αμιάντως αμιγώς αμισθί αμμουδερά αμμωνιακά
 αμνησικάκως αμοίραστα αμοιβαία αμοιβαίως αμολόγητα αμολύντως αμπάλωτα αμπιγιέ
 αμυδρά αμυδρώς αμυντικά αμυντικώς αμφίβολα αμφίπλευρα αμφίρροπα αμφίσημα
 αμφιθεατρικά αμφιρρόπως αμφοτέρωθεν αμόλευτα αμόλυντα αμόνοιαστα αμόρφως
 αμώλυα ανάβαθα ανάγλυφα ανάγωγα ανάερα ανάκατα ανάλαδα ανάλατα ανάλαφρα
 ανάλλαγα ανάλλαχτα ανάλογα ανάμερα ανάμεσα ανάμεσο ανάξια ανάπαλιν ανάπλωρα
 ανάρθρως ανάρια ανάριχτα ανάρμοστα ανάρριχτα ανάρχως ανάσκελα ανάστα ανάστροφα
 ανέγνωμα ανέκαθεν ανέκκλητα ανέκφραστα ανέλπιδα ανέλπιστα ανέμελα ανένδοτα
 ανέξοδα ανέραστα ανέργως ανέσπερα ανέσπλαγχνα ανέσπλαγχνα ανέσπλαχνα
 ανέτοιμα ανέτως ανήθικα ανήμερα ανήσυχα ανίατα ανίατα ανίδρωτα ανίδωτα ανίερα
 ανίσως αναίμακτα αναίμαχτα αναίσθητα αναίσχυντα αναίτια αναβλητικώς
 αναγερτά αναγκαία αναγκαίως αναγκαστικά αναγκαστικώς αναγλύφως αναγνωριστικά
 αναγουλιαστικά αναγωγικώς αναγωγιστικά αναγώγως αναδρομιά αναδρομικά
 αναιδώς αναιμάκτως αναιμικά αναισθήτως αναισχύντως αναιτιολόγητα ανακατωτά
 ανακλητικώς ανακούρκουδα ανακριβώς ανακόλουθα αναληθώς αναλογικά αναλογιστικά
 αναλυτικότερα αναλόγως αναμάρτητα αναμαρτήτως αναμεσής αναμεσίς αναμεταξύ
 αναμφίβολα αναμφίλεκτα αναμφίσημα αναμφιβόλως αναμφισβήτητα ανανεωτικά
 αναντάν μπαμπαντάν αναντάν παπαντάμ αναντίρρητα αναντιλέκτως αναξιοκρατικά
 αναξιοπρεπώς αναξιόπιστα αναπάντεχα αναπαραστατικά αναπαυτικά αναπαυτικώς
 αναποδείκτως αναποδράστως αναπολογήτως αναπολόγητα αναποσπάστως
 αναποτρέπτως αναποφάσιστα αναποφασίστως αναποφεύκτως αναπτυξιακά αναπόδεικτα
 αναπόδραστα αναπόσπαστα αναπότρεπτα αναπόφευκτα αναριθμήτως αναριχτά
 αναρμόδια αναρμόστως αναρριχτά αναρροφητικά αναρροφητικώς αναρχικά αναρχικώς
 ανασταλτικά ανασταλτικώς αναστρέψιμα αναστρόφως ανασυρτά ανασφάλιστα
 ανασχετικά ανατολικά ανατολικώς ανατομικά ανατρεπτικά αναφαίρετα αναφαιρέτως
 αναφομοίωτα αναφορικά αναφορικώς αναχρονιστικά αναχρονιστικώς ανδρεία ανδρείως
 ανδρικά ανδρικώς ανδροπρεπώς ανείπωτα ανεβατά ανεγγυήτως ανεγγύητα ανεγκλήτως
 ανειδοποιήτως ανειλικρινώς ανειρήνευτα ανειρηνεύτως ανεκδιηγήτως ανεκκλήτως
 ανεκμυστήρευτα ανεκπληρώτως ανεκτικά ανεκτικώς ανεκτιμήτως ανεκτώς ανεκφράστως
 ανελαστικά ανελεήμονα ανελεήτως ανελεημόνως ανελευθέρως ανελεύθερα ανελικτικά
 ανελλιπώς ανελπίστως ανεμπόδιστα ανενδοίαστα ανενδοιάστως ανενδότως ανενεργώς
 ανεντίμως ανενόχλητα ανεξάρτητα ανεξέλεγκτα ανεξέταστα ανεξήγητα ανεξίκακα
 ανεξαίρετα ανεξαιρέτως ανεξακρίβωτα ανεξακριβώτως ανεξαλείπτως ανεξαντλήτως
 ανεξελέγκτως ανεξερευνήτως ανεξετάστως ανεξηγήτως ανεξιθρήσκως ανεξικάκως
 ανεξιχνιάστως ανεξοφλήτως ανεξόδως ανεορτάστως ανεπάντεχα ανεπίγνωστα
 ανεπίληπτα ανεπίσημα ανεπίστρεπτα ανεπίστροφα ανεπαίσθητα ανεπαίσχυντα
 ανεπαισθήτως ανεπαισχύντως ανεπαναλήπτως ανεπανορθώτως ανεπανόρθωτα ανεπαρκώς
 ανεπεξεργάστως ανεπηρέαστα ανεπηρεάστως ανεπιβεβαιώτως ανεπιγνώστως
 ανεπιδότως ανεπιεικώς ανεπιθυμήτως ανεπικαίρως ανεπιλύτως ανεπισήμως
 ανεπιστημονικώς ανεπιστρέπτως ανεπιστρεπτί ανεπιστρόφως ανεπιτήδεια
 ανεπιτηδείως ανεπιτηδεύτως ανεπιτηρήτως ανεπιτρέπτως ανεπιτυχώς ανεπιφυλάκτως
 ανεράστως ανερμήνευτα ανερματίστως ανερμηνεύτως ανεσπέρως ανετοίμως ανευθύνως
 ανευλογήτως ανευλόγητα ανευφάνταστα ανεφίκτως ανεφαρμόστως ανεφοδιάστως
 ανεόρταστα ανεύθυνα ανηθίκως ανηκέστως ανηλεώς ανημέρως ανησυχαστικά
 ανησυχητικά ανησύχως ανηφορικά ανθεκτικώς ανθελληνικά ανθελληνικώς
 ανθηρώς ανθρωπίνως ανθρωπινά ανθρωπιστικά ανθρωπιστικώς ανθρωπολογικά
 ανθρωπομορφικά ανθρώπινα ανθυγιεινά ανθυγιεινώς ανθυποβρυχιακά ανιάτως ανιέρως
 ανιαρώς ανιδιοτελώς ανιδρώτως ανικάνως ανικανοποίητα ανικανοποιήτως ανισοβαρώς
 ανισορρόπως ανισοϋψώς ανιστορήτως ανιστόρητα ανιστόρητα ανισχύρως ανισόρροπα
 ανισότιμα ανοήτως ανοδικά ανοδικώς ανοθεύτως ανοικοκύρευτα ανοικοκύρευτα
 ανοιξιάτικα ανοιχτά ανοιχτοχέρικα ανοιχτόκαρδα ανοιχτόχερα ανομοίως
 ανομοιωτικά ανομοιόμορφα ανομοιόμορφα ανομολογήτως ανομολόγητα ανορέκτως
 ανοργάνωτα ανοργανώτως ανορθογράφως ανορθοδόξως ανορθολογικά ανορθωτικά
 ανορθόδοξα ανοσίως ανουσίως ανοχυρώτως ανοϊκά ανούσια αντάμα αντάντε αντάξια
 αντάτζιο αντίθετα αντίκρα αντίκρια αντίκρυ αντίξοα αντίπερα αντίπροχθες
 αντίρροπα αντίρροπα αντίστοιχα αντίστροφα ανταγωνιστικά ανταγωνιστικώς
 αντανακλαστικώς ανταντίνο ανταξίως ανταποδοτικά ανταποδοτικώς ανταρτικά
 αντεθνικώς αντεπαναστατικά αντεπαναστατικώς αντεπιστημονικά αντεπιστημονικώς
 αντεργατικώς αντηχητικώς αντιαγροτικά αντιαεροπορικώς αντιαθλητικώς
 αντιαναπτυξιακά αντιαφροδισιακά αντιβασιλικά αντιγραφικά αντιδημοκρατικώς
 αντιδημοτικώς αντιδογματικά αντιδραστικά αντιδραστικώς αντιδυναστικώς
 αντιεπιστημονικώς αντιευρωπαϊκά αντιθέτως αντιθεατρικά αντιθεατρικώς
 αντιθετικώς αντιιμπεριαλιστικά αντιιμπεριαλιστικός αντικαθεστωτικώς
 αντικανονικά αντικειμενικά αντικειμενικώς αντικοινοβουλευτικά αντικοινωνικά
 αντικομματικά αντικομματικώς αντικρινά αντικριστά αντικρύ αντικυβερνητικά
 αντιλαϊκά αντιλαϊκώς αντιληπτά αντιληπτικά αντιληπτικώς αντιμέτωπα
 αντιμελοδραματικά αντιμεταθετικά αντιμεταθετικά αντιμετώπως αντιμοναρχικώς
 αντινομιστικά αντιξόως αντιοικονομικά αντιπέραν αντιπαθητικά αντιπαθώς
 αντιπατριωτικά αντιπατριωτικώς αντιποιητικά αντιπολιτευτικά αντιπολιτευτικώς
 αντιπροπέρσι αντιπροσωπευτικά αντιπροσωπευτικώς αντιπροχθές αντιπροχτές
 αντιρρητικώς αντιρρόπως αντισεισμικά αντισηπτικά αντισηπτικώς αντισοβιετικά
 αντισπασμωδικώς αντισταθμιστικά αντιστασιακά αντιστικτικά αντιστοίχως
 αντιστρατιωτικώς αντιστρεπτά αντιστρόφως αντισυμβατικά αντισυνταγματικά
 αντιφατικά αντιφατικώς αντιφεμινιστικά αντιφιλοσοφικά αντιφωνικά
 αντρίκεια αντρίκια αντρειωμένα αντρικά αντωνυμικώς ανυπάρκτως ανυπέρβλητα
 ανυπεράσπιστα ανυπεράσπιστα ανυπερασπίστως ανυπερβλήτως ανυπερθέτως
 ανυποθήκευτα ανυπολήπτως ανυπολογίστως ανυπολόγιστα ανυπομόνως ανυποστάτως
 ανυποχωρήτως ανυποχώρητα ανυποψίαστα ανυποψίαστα ανυποψιάστως ανυπόγραφα
 ανυπόκριτα ανυπόληπτα ανυπόμονα ανυπόνοιαστα ανυπόπτως ανυπόστατα ανυπότακτα
 ανυπόφερτα ανυπόφορα ανυστερόβουλα ανυστερόβουλα ανυψωτικώς ανωδύνως ανωμάλως
 ανωνύμως ανωρίμως ανωτέρω ανωφερώς ανόητα ανόθευτα ανόμοια ανόργανα ανόρεκτα
 ανόσια ανύποπτα ανύποπτα ανύχτωτα ανώδυνα ανώμαλα ανώμαλα ανώνυμα ανώριμα
 ανώφελα ανώφελα αξέμπλεχτα αξέστως αξέχαστα αξήγητα αξεδίψαστα αξεδίψαστα
 αξεδιάλυτα αξεθύμαστα αξεκαθάριστα αξεκόλλητα αξελόγιαστα αξεμπέρδευτα
 αξεπέραστα αξεπούλητα αξερίζωτα αξεσκάλιστα αξεσκάλιστα αξεσκόλιστα αξετίμητα
 αξεχώριστα αξημέρωτα αξιέπαινα αξιακά αξιεπαίνως αξιοδάκρυτα αξιοδακρύτως
 αξιοθαυμάστως αξιοθαύμαστα αξιοθρήνητα αξιοθρήνητα αξιοθρηνήτως αξιοκατάκριτα
 αξιοκαταφρονήτως αξιοκαταφρόνητα αξιοκρατικά αξιοκρατικώς αξιολάτρευτα
 αξιολογικά αξιολογικώς αξιολυπήτως αξιολόγως αξιολύπητα αξιοπίστως
 αξιοπρεπώς αξιοπρόσεκτα αξιοσέβαστα αξιοσημείωτα αξιοχρέως αξιωματικά
 αξιόλογα αξιόμαχα αξιόμαχα αξιόπιστα αξιόπρεπα αξιόπρεπα αξιόχρεα αξιώς
 αξονικά αξόδευτα αξόμπλιαστα αξόφλητα αξύπνητα αοράτως αορίστως αοριστολογικά
 απ'ευθείας απά απάν' απάνεμα απάνθρωπα απάνθρωπα απάνου απάνω απάστρευτα
 απέ απέναντι απέξω απέπτως απέραντα απέριττα απής απίεστα απίθανα απίκο απίκου
 απίστομα απίστως απαίδευτα απαγγελτικά απαγορευτικά απαγωγικώς απαζάρευτα
 απαιδεύτως απαισιόδοξα απαιτητά απαιτητικά απαλά απαλειπτικώς απαλώς
 απανταχού απανταχόθεν απανωτά απαξιωτικά απαράβατα απαράβλητα απαράγραπτα
 απαράδεχτα απαράκλητα απαράλειπτα απαράληπτα απαράλλακτα απαράλλαχτα
 απαράσκευα απαρέγκλιτα απαρένθετα απαραίτητα απαραβάτως απαραβίαστα
 απαραβλήτως απαραγράπτως απαραδέκτως απαραιτήτως απαρακάλεστα απαρακάλετα
 απαρακινήτως απαρακλήτως απαρακολουθήτως απαρακολούθητα απαραλήπτως
 απαραλλάκτως απαραλλήλιστα απαραλληλίστως απαραμίλλως απαραμείωτα απαραμείωτα
 απαραμυθήτως απαραμύθητα απαραπλάνητα απαραπλανήτως απαρασάλευτα απαρασαλεύτως
 απαρασκεύαστα απαρασκεύαστα απαρασκεύως απαρατήρητα απαρατηρήτως απαραφυλάκτως
 απαραχάρακτα απαραχάραχτα απαραχαράκτως απαραχωρήτως απαραχώρητα απαρεγκλίτως
 απαρεμπόδιστα απαρενθέτως απαρενοχλήτως απαρενόχλητα απαρεξήγητα απαρεξηγήτως
 απαρηγόρητα απαρορμήτως απαρρησίαστα απαρρησιάστως απαρχής απαρωδήτως
 απασπάτευτα απατηλά απατηλώς απείθαρχα απείρως απεγνωσμένα απεγνωσμένως
 απειλητικά απειλητικώς απειράκις απειραγάθως απειροελάχιστα απειροστά
 απελευθερωτικώς απελπισμένα απελπιστικά απελπιστικώς απεναντίας απεράντως
 απερίσκεπτα απερίσκεφτα απερίσπαστα απερίττως απερίφραστα απεργιακά
 απερηφάνευτα απεριέργως απεριορίστως απεριποίητα απεριποιήτως απερισκέπτως
 απεριφράστως απεριόριστα απευθείας απεχθώς απιέστως απιθάνως απιστεύτως απλά
 απλέτως απλήρωτα απλήστως απλανώς απληροφορήτως απληροφόρητα απλησίαστα
 απλογραφικώς απλοελληνικά απλοελληνικώς απλοελληνιστί απλοποιημένα απλοϊκά
 απλωτά απλόχερα απλόχωρα απλώς απνευστί αποβδόμαδα αποβλακωμένα αποβλακωτικά
 αποβραδίς αποβραδινά απογεματινά απογευματινά απογοητευμένα απογοητευτικά
 αποδεδειγμένα αποδεδειγμένως αποδειγμένα αποδεικτά αποδεκτά αποδεχτά
 αποδοκιμαστικώς αποδοτικά αποδοτικώς αποδυναμωτικά αποθαρρυντικά
 αποθεωτικά αποθεωτικώς αποικιακώς αποκάτω αποκαλούθε αποκαλυπτικά
 αποκαρδιωτικά αποκαρδιωτικώς αποκατινά αποκεντρωτικά αποκλειστικά
 αποκληρωτικά αποκληρωτικώς αποκοιμιστικά αποκοιμιστικώς αποκοντά αποκριάτικα
 αποκρουστικά αποκρουστικώς αποκρυφιστικά αποκρύφως απολέμιστα απολέμως
 απολαυστικά απολαυστικώς απολείτουργα απολείτουργο απολιτίστως απολλαπλασίαστα
 απολογητικά απολογητικώς απολυμαντικά απολυτά απολυταρχικά απολυταρχικώς
 απολυτρωτικώς απολύτως απομεσήμερα απομοναχά απομονωμένα απομονωτικά
 απομυθοποιητικά απονήρευτα απονενοημένα απονενοημένως απονύχτερα αποξαρχής
 αποπάζαρα αποπάνω αποπλανητικά αποπλανητικώς αποπληθωριστικά αποπνικτικά
 απορρήτως απορροφητικά απορροφητικώς απορρυθμιστικά απορρυπαντικά αποσαθρωτικά
 αποσπέρας αποσπασματικά αποσπασματικώς αποσπερίς αποσπερνά αποσπόντα
 αποστολικά αποστομωτικά αποσυμφορητικά αποσυμφορητικώς αποσυρτά αποσχιστικά
 αποτελεσματικά αποτελεσματικώς αποτραβηγμένα αποτρεπτικά αποτρεπτικώς
 αποτροπαϊκά αποτρόπαια αποτυχημένα αποτόμως αποφαντικά αποφαντικώς
 αποφασιστικώς αποφατικά αποφατικώς αποφθεγματικά αποφθεγματικώς αποχαυνωμένα
 αποψεσινά αποψινά απούντο απράκτως απραγματοποίητα απραγματοποιήτως απρεπώς
 απριλινά απροίκιστα απροίκως απροβάριστα απροβλέπτως απρογραμμάτιστα
 απροειδοποίητα απροετοίμαστα απροετοιμάστως απροθέσμως απροθέτως απροθύμως
 απροκαλύπτως απροκατάληπτα απροκαταλήπτως απρομελέτητα απρομελετήτως
 απρονόητα απροσάρμοστα απροσέκτως απροσίτως απροσαρμόστως απροσβλήτως
 απροσδιορίστως απροσδιόριστα απροσδοκήτως απροσδόκητα απροσκάλεστα απροσκλήτως
 απροσκύνητα απροσμέτρητα απροσμαχήτως απροσπέλαστα απροσποίητα απροσποιήτως
 απροσφόρως απροσχεδίαστα απροσχεδιάστως απροσχημάτιστα απροσχηματίστως
 απροσόδως απροσώπως απροφάσιστα απροφασίστως απροόπτως απρόβλεπτα απρόθεσμα
 απρόθυμα απρόκλητα απρόκοπα απρόκοφτα απρόοπτα απρόσβλητα απρόσεκτα απρόσεχτα
 απρόσκλητα απρόσκοπτα απρόσμενα απρόσοδα απρόσφορα απρόσωπα απτά απταίστως
 απτόητα απτώς απυρέτως απωανατολικά απωανατολικώς απωθητικά απωθητικώς
 απόγευμα απόδιπλα απόκεντρα απόκοντα απόκοσμα απόκοτα απόκρημνα απόκρυφα
 απόλεμα απόλυτα απόμακρα απόμερα απόνως απόξω απόπασχα απόρθητα απόρρητα
 απόσπερα απόσπερνα απότολμα απότομα απότρυγα απόψε απύρετα αράδα αράθυμα
 αραβικά αραβιστί αραδιαστά αραιά αραιώς αργοσχόλως αργούτσικα αργόσχολα
 αρειμανίως αρεστά αρθρογραφικά αρθρωτά αριά αριθμητά αριθμητικά αριθμητικώς
 αριστερά αριστερόθεν αριστερότερα αριστερώς αριστοκρατικά αριστοκρατικώς
 αριστοτεχνικώς αριστουργηματικά αριστουργηματικώς αριστοφανικά αρκετά
 αρκτικά αρκτικώς αρμοδίως αρμονικά αρμονικώς αρμυρά αρμόδια αρνητικά αρπακτικά
 αρπαχτά αρπαχτικά αρρήκτως αρραγώς αρρενωπά αρρενωπώς αρρυθμίστως αρρωστημένα
 αρρύθμως αρτίως αρτζιμπούρτζι αρτηριακά αρτηριογραφικά αρτιμελώς αρτσιβούρτσι
 αρχήθεν αρχαιολατρικά αρχαιόθεν αρχαϊκά αρχαϊκώς αρχαϊστί αρχεγόνως αρχειακά
 αρχικώς αρχοντικά αρχοντοχωριάτικα αρχύτερα αρόδο αρόδου ασάλευτα ασέμνως
 ασίγαστα ασίγητα ασαβούρωτα ασαλεύτως ασαφώς ασβολερά ασεβώς ασεισμικά ασελγώς
 ασημειώτως ασηπτικά ασηπτικώς ασθενικά ασθενικώς ασθενώς ασιανά ασιγήτως
 ασκίαστα ασκαλντί ασκανδάλιστα ασκανδαλίστως ασκαρδαμυκτί ασκημούτσικα
 ασκητικώς ασκλάβωτα ασκοτείνιαστα ασκούπιστα ασκόπευτα ασκόπως ασκόρπιστα
 ασμένως ασορτί ασουλούπωτα ασουρούπωτα ασούβλιστα ασπέδιστα ασπαστά ασπλάγχνως
 ασπούδαστα ασπούδαχτα ασπριδερά ασπόρως ασσυριακά ασσυριακά αστάθμητα
 αστήριχτα ασταθώς ασταμάτητα αστεία αστείρευτα αστείως αστειρεύτως αστεροειδώς
 αστεφάνωτα αστηλιτεύτως αστηρίκτως αστιγμάτιστα αστικά αστράγγιστα αστράτευτα
 αστραπηδόν αστραπιαία αστραπιαίως αστρατεύτως αστρατολογήτως αστρατολόγητα
 αστρικά αστρικώς αστρολογικά αστρονομικά αστυνομικά αστόλιστα αστόργως
 αστόχως ασυγκίνητα ασυγκράτητα ασυγκρίτως ασυγκρότητα ασυγχρόνιστα ασυγχώρητα
 ασυζήτητα ασυζητητί ασυκοφάντητα ασυλλήπτως ασυλλόγιστα ασυμβάτως ασυμβίβαστα
 ασυμμάζευτα ασυμμέτρως ασυμμόρφωτα ασυμπάθητα ασυμπάθητα ασυμπάθιστα
 ασυμπλήρωτα ασυμπληρώτως ασυμπτύκτως ασυμπτώτως ασυμφόρως ασυμφώνως ασυνάρτητα
 ασυνήθιστα ασυνήθως ασυναίρετα ασυναίσθητα ασυναγώνιστα ασυναιρέτως
 ασυναρτήτως ασυνδέτως ασυνδυάστως ασυνδύαστα ασυνείδητα ασυνειδήτως
 ασυνεπώς ασυνεχώς ασυνθηκολογήτως ασυνθηκολόγητα ασυννέφιαστα ασυνοδεύτως
 ασυνταίριαστα ασυνταυτίστως ασυντονίστως ασυντρόφευτα ασυντρόφιαστα
 ασυνόδευτα ασυστάτως ασυστηματοποίητα ασυστόλως ασυσχέτιστα ασφαλιστικά
 ασφαλώς ασφουγγάριστα ασφούγγιστα ασφούγγιχτα ασφυκτικά ασφυκτικώς ασφυχτικά
 ασχήμως ασχεδίαστα ασχημάτιστα ασχηματίστως ασχημούτσικα ασχολίαστα
 ασωφρονίστως ασωφρόνιστα ασύγγνωστα ασύγκριτα ασύγκριτος ασύγχρονα ασύδοτα
 ασύμμετρα ασύμπτυκτα ασύμπτωτα ασύμφορα ασύμφωνα ασύνδετα ασύνειδα ασύνετα
 ασύνταχτα ασύρματα ασύστατα ασύστολα ασύχαστα ασύχναστα ασώτως ατάκτως
 ατάραχα ατάραχτα ατάσθαλα ατέγκτως ατέλειωτα ατέμπο ατέρμονα ατέχνως αταίριαγα
 αταίριαχτα αταβιστικά ατακτοποίητα αταλάντευτα αταλαιπωρήτως αταλαιπώρητα
 αταπείνωτα αταπεινώτως αταράχως ατασθάλως αταχτοποίητα ατελέσφορα ατελείωτα
 ατελεσφορήτως ατελεσφόρητα ατελεσφόρως ατελευτήτως ατελεύτητα ατελωνίστως
 ατελώνιστα ατελώς ατενώς ατερμάτιστα ατερματίστως ατζαμίδικα ατζιτάτο
 ατημελήτως ατιμωρήτως ατιμωρητί ατιμώρητα ατλαζωτά ατμήτως ατοίμαστα ατομικά
 ατομικιστικώς ατομικώς ατομιστικά ατομιστικώς ατράνταχτα ατραγούδιστα
 ατροποποίητα ατροποποιήτως ατρόμητα ατρύγητα ατσάκιστα ατσίκνιστα ατσαλάκωτα
 ατυχώς ατόλμως ατόνως ατόφια ατύπως αυγερινά αυγινά αυγουστιάτικα αυθαίρετα
 αυθεντικά αυθεντικώς αυθημερόν αυθορμήτως αυθυπόστατα αυθωρί αυθωρεί αυθόρμητα
 αυλικά αυστηρά αυτάρεσκα αυταπόδεικτα αυταπόδειχτα αυταρχικά αυτενέργητα
 αυτεξούσια αυτεπάγγελτα αυτεπαγγέλτως αυτοβοεί αυτοβούλως αυτοδικαίως
 αυτοκλήτως αυτοκρατορικά αυτοκριτικά αυτολεξεί αυτομάτως αυτονοήτως
 αυτονόητα αυτονόμως αυτοπαθώς αυτοπροαίρετα αυτοπροαιρέτως αυτοπροσώπως
 αυτοσαρκαστικά αυτοστιγμεί αυτοσχέδια αυτοσχεδίως αυτοτελώς αυτουργά αυτουσίως
 αυτοχειρί αυτού αυτούσια αυτόβουλα αυτόθι αυτόκλητα αυτόματα αυτόνομα
 αφάγωτα αφάνταστα αφαιρετά αφαιρετικά αφανέρωτα αφαντάστως αφανώς αφατριάστως
 αφειδώς αφελώς αφεντάδικα αφεντάδικα αφερέγγυα αφετηριακά αφετηριακά αφετουόζο
 αφηγηματικά αφηρημένα αφθόνως αφιερωματικά αφιλάνθρωπα αφιλοκερδώς
 αφιλοστόργως αφιλοσόφητα αφιλόκερδα αφιλόξενα αφιλόστοργα αφομοιωμένα
 αφοπλιστικά αφορήτως αφοριστικά αφορμάριστα αφορολογήτως αφορολόγητα
 αφρικανικά αφρόντιστα αφόρητα αφύλακτα αφύλαχτα αφύσικα αφώτιστα αφ’ ετέρου
 αχάριστα αχαλίνωτα αχαλιναγώγητα αχαμνά αχαρακτήριστα αχαραχτήριστα
 αχειραγώγητα αχειροποίητα αχειροτόνητα αχλευάστως αχλεύαστα αχνά αχνιστά
 αχρέωτα αχρήστως αχρεία αχρείως αχρεωστήτως αχρεώστητα αχρεώτως αχρησιμοποίητα
 αχρονολογήτως αχρονολόγητα αχρωμάτιστα αχρόνιαστα αχρόνιστα αχρόνως αχρόως
 αχτιδωτά αχόλιαστα αχόλως αχόρταγα αχόρταστα αψά αψήφιστα αψίθυμα αψίκορα
 αψαχούλευτα αψηλά αψηλάφητα αψιά αψιδωτά αψιθύμως αψικόρως αψυχαγώγητα
 αψυχολόγητα αψύχως αψώνιστα αόκνως αόπλως αόρατα αόριστα αόσμως αύθις αύριο
 αὐθωρεί βάδην βάναυσα βάρυπνα βάσει βάσιμα βέβαια βέβηλα βίαια βαθιά βαθμηδόν
 βαθμιδωτά βαθμολογικά βαθουλωτά βαθυσεβάστως βαθυστόχαστα βαθύτατα βακχικά
 βαλκανικά βαναύσως βανδαλικά βανδαλικώς βαρέως βαρβαρικά βαρβαρικώς βαρβαριστί
 βαριά βαρυθύμως βαρυσήμαντα βαρυσημάντως βαρύθυμα βαρύθυμα βαρύτατα βασίμως
 βασανιστικώς βασικά βασικώς βασιλικά βασιλικώς βασταγερά βατά βδελυρά βεβαίως
 βεβιασμένα βελτιωτικά βενετικά βενετσιάνικα βερεσέ βερμπαλιστικά βιαίως
 βιβλιακά βιδωτά βιζαβί βιολογικά βιολογικώς βιομηχανικά βιονομικά βιοποριστικά
 βιοτεχνικώς βιοτεχνολογικά βιοχημικά βλάσφημα βλαβερά βλαβερώς βλακωδώς
 βλαπτικώς βλοσυρά βοήθεια:γρήγορη δημιουργία/επιρ- βοερά βοηθητικά βολετά
 βορείως βορειανατολικά βορειοανατολικά βορειοδυτικά βορινά βουβά βουερά
 βουλγαρικά βουλγαριστί βουστροφηδόν βουτηχτά βραδέως βραδιάτικα βραδινά
 βραχέως βραχνά βραχυγραφικά βραχυλογικά βραχυλογικώς βραχυπρόθεσμα
 βρετανικά βρομερά βροντερά βροχηδόν βρόμικα βυζαντινά γαζωτά γαλλικά γαλλιστί
 γαργαλιστικά γαϊδουρινά γειρτά γελαστά γελοία γελοίως γελοιωδώς γεναριάτικα
 γενικά γενικευτικά γενικώς γενναία γενναίως γενναιοδώρως γενναιοφρόνως
 γερά γερμανικά γεροντικά γερτά γεωδαιτικώς γεωδυναμικά γεωθερμικά γεωκεντρικά
 γεωμαγνητικά γεωμετρικά γεωπολιτικά γεωτεχνικά γεωφυσικά γεωχημικά γηριατρικά
 γιαλαντζί γιαπωνέζικα γιαχνιστά γιγαντιαία γιοκ γιορταστικά γιορτερά γιορτινά
 γκανγκστερικά γκαρδιακά γκρινιάρικα γκρόσο μόντο γλαυκά γλαφυρά γλαφυρώς
 γλυκά γλυκερά γλυκομίλητα γλυφά γλωσσολογικά γνήσια γνωσιολογικά γνωστικά
 γοητευτικά γονίμως γονατιστά γονοτυπικά γονυπετώς γοργά γοργώς γουρλίδικα
 γούτσου γούτσου γρήγορα γραικιστί γραμμή γραμματειακά γραμματικά γραμματικώς
 γραμμικώς γραμμοειδώς γραμμωτά γραπτά γραπτώς γραφειοκρατικά γραφειοκρατικώς
 γραφολογικά γραφολογικώς γραφτά γριφοειδώς γριφωδώς γρουσούζικα γρυπά
 γυμνασιακά γυμνώς γυναικολογικά γυναικολογικώς γυναικοπρεπώς γυναικωτά γυριστά
 γύροθεν γύρω γύρωθε δήθεν δίκαια δίκην δίπλα δαγκωτά δαιμονίως δαιμονικά
 δακτυλιοειδώς δαμασκηνά δανέζικα δανειακά δανεικά δανικά δαπανηρά δαπανηρώς
 δαψιλώς δειγματοληπτικά δειλά δεκάκις δεκαπλά δεκτώς δελέγκου δελεαστικά
 δεξιά δεξιοτεχνικά δεξιοτεχνικώς δεξιόθεν δεξιότερα δεξιώς δεοντολογικά
 δερβίσικα δεσμευτικά δεσμευτικώς δεσποτικά δεσποτικώς δετά δευτερευόντως
 δευτερογενώς δευτερόπρυμα δεχτά δεόντως δεύρο δεύτε δηκτικά δηκτικώς δηλονότι
 δημιουργικά δημιουργικώς δημογραφικά δημογραφικώς δημοκρατικά δημοκρατικώς
 δημοσίως δημοσιογραφικά δημοσιονομικά δημοσιοϋπαλληλικά
 δημόσια διάμασχα διάνα διάπλατα διάπυρα διάσπαρτα διάχυτα διαβεβαιωτικά
 διαβλητά διαβλητικώς διαβοήτως διαβολεμένα διαβολικά διαβολικώς διαβρωτικά
 διαγωνίως διαγώνια διαδικτυακά διαδοχικά διαδοχικώς διαδραστικά διαζευχτικά
 διακανονιστικά διακαώς διακηρυκτικά διακοσμητικά διακριτικά διακριτικώς
 διαλεκτικώς διαλλακτικά διαλλακτικώς διαλλαχτικά διαλυτικά διαλυτικώς
 διαμερισματικά διαμετρικά διαμιάς διαμορφωτικά διαμπερώς διανοητά διανοητικά
 διαπαντός διαπεραστικά διαπερατά διαπρεπώς διαπύρως διαρκώς διαρρήδην
 διασαφηνιστικά διασαφητικά διασκεδαστικά διασκεδαστικώς διασταλτά διασταλτικά
 διαστρεβλωτικά διαστρεβλωτικώς διασυνδετικά διασυνοριακά διασωματειακά
 διατόρως διαυγώς διαφανώς διαφερόντως διαφορετικά διαφορετικώς διαφοροτρόπως
 διαφόρως διαχειριστικά διαχειριστικώς διαχρονικά διαχυτικά διαχυτικώς διδακτά
 διδακτικώς διδαχτικά διεγερτικά διεγερτικώς διεθνώς διεξοδικά διεξοδικώς
 διερευνητικά διερευνητικώς διερμηνευτικά διεστραμμένα διεστραμμένως
 διευκρινιστικώς διηγηματικά διηγηματικώς διηθητά διηνεκώς διθυραμβικά
 δικαιολογημένα δικαιολογητικά δικαιωματικά δικαιωματικώς δικανικά δικαστικώς
 δικονομικά δικονομικώς δικτατορικά δικτατορικώς δικτυακά δικτυωτά διμερώς
 διοικητικά διοικητικώς διονυσιακά διπλά διπλάσια διπλανά διπλασίως διπλοπόδι
 δις διστακτικά διστακτικώς δισταχτικά δισυλλάβως δισύλλαβα διττά διχαλωτά
 διχοτομικώς διχτυωτά διό διόλου δοκίμως δοκιμαστικά δοκιμαστικώς δολίως δολερά
 δολοφονικά δολοφονικώς δοξαρωτά δοξαστικά δοξαστικώς δοτά δουλοπρεπώς
 δραματικά δραματικώς δραματολογικά δραματολογικώς δραστήρια δραστηρίως
 δραστικώς δρεπανοειδώς δριμέως δρομαίως δροσερά δυνάμει δυναμικά δυναμικώς
 δυναστικώς δυνατά δυνητικά δυνητικώς δυσάρεστα δυσανάγνωστα δυσανάλογα
 δυσαναλόγως δυσαρέστως δυσβάστακτα δυσβάστακτα δυσβάσταχτα δυσβαστάκτως
 δυσδιακρίτως δυσηλεκτραγωγά δυσηχαγωγά δυσθερμαγωγά δυσθύμως δυσκάμπτως
 δυσκινήτως δυσκόλως δυσμενώς δυσμόθεν δυσμόρφως δυσνοήτως δυσνόητα δυσοίωνα
 δυσπίστως δυστρόπως δυστυχώς δυσχρήστως δυτικά δυτικώς δω δωρεάν δόκιμα δόλια
 δύσκολα δύσμορφα δύσπιστα δύστροπα δύσχρηστα δώθε είτα εβραϊστί εγγύθεν εγγύς
 εγκάρσια εγκαίρως εγκαρδίως εγκαρδιωτικά εγκαρσίως εγκεφαλικά εγκλείστως
 εγκληματικώς εγκυκλοπαιδικά εγκωμιαστικά εγούγια εγχειρητικά εγωιστικά
 εγωπαθώς εδά εδαφιαία εδαφικά εδαφολογικά εδεκεί εδεπά εδωδά εδώ εδώθε
 εθελοντικώς εθελουσίως εθελούσια εθιμοτυπικά εθιμοτυπικώς εθνικά εθνογραφικά
 εθνοκεντρικά εθνολογικώς εθνοπρεπώς ειδάλλως ειδαλλιώς ειδεχθώς ειδημόνως
 ειδικά ειδικώς ειδυλλιακά ειδωλολατρικά εική εικαστικά εικονικά εικονικώς
 εικονογραφικώς εικότως ειλικρινά ειλικρινώς ειρηνευτικά ειρηνικά ειρηνικώς
 ειρωνικώς εισέτι εισαγωγικά εισαγωγικώς εισηγητικά εκ των προτέρων εκάς
 εκατέρωθεν εκατοντάκις εκατονταπλάσια εκβιαστικά εκβιαστικώς εκδήλως
 εκδικήτρα εκδικητικά εκεί εκείθε εκείθεν εκειά εκειδά εκθαμβωτικά εκθαμβωτικώς
 εκθειαστικώς εκθετικά εκκαθαριστικά εκκαθαριστικώς εκκεντρικά εκκεντρικώς
 εκκλησιαστικώς εκκωφαντικά εκλεκτά εκλεχτά εκλογικά εκμαυλιστικά
 εκμυστηρευτικώς εκνευρισμένα εκνευριστικά εκνευριστικώς εκνόμως εκουσίως
 εκπληκτικά εκπληκτικώς εκποδών εκπολιτιστικά εκπολιτιστικώς εκπροθέσμως
 εκπτωτικά εκπτωτικώς εκρηκτικά εκρηκτικώς εκρύθμως εκστατικά εκστατικώς
 εκτατά εκτατικά εκτελεστά εκτενώς εκτρωματικώς εκτός εκφοβιστικά εκφραστικά
 εκφυλιστικά εκόντως ελάχιστα ελαστικά ελατά ελαττωματικώς ελαφρά ελαφρώς
 ελεγειακά ελεεινά ελεεινώς ελεημονικώς ελεημόνως ελευθέρως ελευθεροστόμως
 ελεύθερα ελικτικά ελικτικώς ελικωτά ελισαβετιανά ελιτίστικα ελκυστικά ελλείψει
 ελληνικά ελληνιστί ελληνοτρόπως ελληνότροπα ελλιπώς ελλόγως εμβρυακά εμβρυϊκά
 εμμέτρως εμμίσθως εμμανώς εμμελώς εμμηναγωγά εμμηνορροϊκά εμμονικά εμπαθώς
 εμπαικτικώς εμπειρικά εμπεριστατωμένα εμπιστευτικά εμπιστευτικώς εμπράκτως
 εμπρηστικά εμπρηστικώς εμπροθέσμως εμπρόθεσμα εμπρόθετα εμπρός εμφανισιακά
 εμφαντικώς εμφανώς εμφατικά εμφύτως εμψυχωτικά ενάντια ενίοτε εναγωνίως
 εναγώς εναλλάξ εναλλακτικά εναλλακτικώς εναντίον εναντίως εναντιομόρφως
 εναρέτως εναργέστερα ενδίκως ενδελεχώς ενδεχομένως ενδιάθετα ενδιάμεσα
 ενδιαμέσως ενδοιαστικώς ενδομυϊκά ενδομύχως ενδονοσοκομειακά ενδοσυνεδριακά
 ενδοφλεβίως ενδόθεν ενδόμυχα ενδόξως ενεδρευτικώς ενενηκοστά ενεργά ενεργητικά
 ενετικά ενημερωτικά ενθάδε ενθένδε ενθέρμως ενθαρρυντικά ενθαρρυντικώς
 ενθουσιαστικώς ενθουσιωδώς ενιαία ενιαίως ενιαχού ενισχυτικώς εννεάκις
 εννόμως ενοποιά ενοριακά ενοχλητικά ενστίκτως ενστικτωδώς ενσυνειδήτως εντάξει
 εντατικά ενταύθα εντελώς εντεταμένα εντεψίζικα εντεύθεν εντονότατα εντροπαλά
 εντωμεταξύ εντόνως εντός ενυπογράφως ενυπόγραφα ενωρίς ενόρκως ενόψει ενώπιον
 εξάλλου εξάλλως εξάπαντος εξής εξίσου εξαίρετα εξαίσια εξαίφνης εξαγνιστικώς
 εξαιρέτως εξαιρετικά εξαιρετικώς εξαισίως εξακολουθητικά εξακολουθητικώς
 εξακριβωμένα εξαμηνιαίως εξαναγκαστικώς εξαντλητικά εξαντλητικώς εξαπίνης
 εξαπλασίως εξαρτημένα εξαρχής εξασθενητικώς εξατομικευμένα εξελικτικά
 εξεπίτηδες εξεπιτούτου εξεταστικά εξευμενιστικά εξευτελιστικά εξηγητικά
 εξισορροπητικά εξισωτικά εξισωτικώς εξολοθρευτικώς εξολοκλήρου εξομοιωτικά
 εξομολογητικά εξομολογητικώς εξονειδιστικώς εξοντωτικά εξονυχιστικά
 εξοργιστικά εξουθενωτικά εξουσιαστικά εξού εξτρεμιστικά εξυγιαντικά εξυμνητικά
 εξωδίκως εξωδικαστικά εξωθεσμικά εξωθεσμικά εξωπραγματικά εξωπραγματικώς
 εξωραϊστικώς εξωστικώς εξωστρεφώς εξωσυζυγικά εξωσυζυγικώς εξωτερικά
 εξωφρενικά εξόν εξόφθαλμα εξόχως εξώδικα εξώρας εξώτατα εξώτερον εορταστικά
 επά επάλληλα επάνου επάνω επάξια επέκεινα επίβουλα επίζηλα επίκτητα επίμονα
 επίπονα επίσημα επίσης επίτηδες επίτομα επίφοβα επαέ επαίσχυντα επαγγελματικά
 επαγγελτικά επαγγελτικώς επαγωγικά επαγωγικώς επαγωγώς επαινετά επαινετικά
 επαινετώς επαισχύντως επακριβώς επακτά επακόλουθον επαλλήλως επαμφοτεριζόντως
 επαναληπτικά επαναληπτικώς επαναστατικά επαναστατικώς επανειλημμένα
 επανωτά επαξίως επαρκώς επαρχιακά επαύριον επειγόντως επεισοδιακά επεισοδιακώς
 επεξηγηματικά επεξηγηματικώς επιβαρυντικά επιβαρυντικώς επιβατηγά
 επιβεβαιωτικά επιβεβαιωτικώς επιβλαβώς επιβλητικά επιβλητικώς επιβοηθητικά
 επιγραμματικά επιγραμματικώς επιδέξια επιδεικτικά επιδεικτικώς επιδειχτικά
 επιδεξίως επιδερμικά επιδερμικώς επιδιαιτητικώς επιδιορθωτικώς επιδοκιμαστικά
 επιεικώς επιζήλως επιζήμια επιζημίως επιθετικά επιθετικώς επιθεωρησιακά
 επιθυμητά επιθυμητώς επικά επικίνδυνα επικερδώς επικινδύνως επικλινώς
 επικουρικώς επικριτικώς επικτήτως επικυριαρχικώς επικώς επιλήψιμα επιλεκτικά
 επιμελητηριακά επιμελώς επιμόνως επιμόχθως επινοητικά επινοητικώς επιπλέον
 επιπροσθέτως επιπρόσθετα επιπόλαια επιπόνως επιρρεπώς επιρρηματικά
 επισήμως επισκευαστικά επισταμένως επιστημονικά επιστημονικώς επισφαλώς
 επιτήδεια επιτακτικά επιτακτικώς επιτατικώς επιταυτού επιταχυντικά
 επιτηδείως επιτηδευμένα επιτιμητικά επιτιμητικώς επιτοπίως επιτρεπτά
 επιτροχάδην επιτυχημένα επιτυχώς επιτόμως επιτόπια επιτόπου επιφανειακά
 επιφανώς επιφυλακτικά επιφυλακτικώς επιφωνηματικά επιφόβως επιχαρίτως
 επιχωρίως εποικιστικώς εποικοδομητικά εποικοδομητικώς επονείδιστα επονειδίστως
 εποπτικώς επουλωτικώς επουράνια επουρανίως επουσιωδώς εποχιακά επτάκις
 επταπλάσια επωδύνως επωνύμως επωφελώς επώδυνα επώνυμα ερήμην ερασιτεχνικά
 ερασμιακά ερασμιακώς ερατεινά ερατεινώς εργασιακά εργαστηριακά εργολαβικώς
 ερευνητικά ερευνητικώς ερημικά ερημικώς εριστικά εριστικώς ερμηνευτικά
 ερμητικώς ερρωμένως ερρύθμως ερυθρά ερυθρωπά ερωτηματικά ερωτηματικώς ερωτικά
 εσαεί εσθονικά εσκεμμένα εσπερινά εσπευσμένα εσπευσμένως εστιακά εσφαλμένα
 εσχάτως εσχατολογικά εσωκλείστως εσωτερικά εσωτερικώς εσώκλειστα εσώψυχα ετά
 εταστικώς ετεροβαρώς ετερογενώς ετεροδόξως ετεροειδώς ετεροσκεδαστικά
 ετερόκλητα ετησίως ετοίμως ετρουσκικά ετσά ετσιθελικά ετυμολογικά ετυμολογικώς
 ευέλικτα ευέξαπτα ευήθως ευήχως ευαγώς ευανάγνωστα ευαναγνώστως ευαποδείκτως
 ευαρμόστως ευβούλως ευγενέστερα ευγενικά ευγενικώς ευγλώττως ευγνωμόνως
 ευδιάκριτα ευδιακρίτως ευδοκίμως ευδόκιμα ευεργετικά ευεργετικώς ευηλεκτραγωγά
 ευθέως ευθαρσώς ευθεία ευθερμαγωγά ευθηνά ευθυγράμμως ευθυμογραφικώς ευθυτενώς
 ευθύμως ευθύς ευκάμπτως ευκίνητα ευκαίρως ευκαιριακά ευκαταφρονήτως
 ευκινήτως ευκλεώς ευκρινώς ευκόλως ευκόσμως ευλαβητικώς ευλαβικά ευλαβικώς
 ευλογητά ευλογητικώς ευλογοφανώς ευλυγίστως ευλόγως ευλύγιστα ευμαθώς
 ευμενώς ευμετάβλητα ευμεταβλήτως ευνοήτως ευνοϊκά ευνοϊκώς ευνόητα ευπίστως
 ευπαρουσίαστα ευπαρουσιάστως ευπειθώς ευπρεπώς ευπροσώπως ευπρόσωπα ευπόρως
 ευρυμαθώς ευρωπαϊκά ευρύθμως ευρύχωρα ευρώστως ευσεβάστως ευσεβώς ευσπλαγχνικά
 ευσπλαχνικά ευσταθώς ευσταλώς ευστρόφως ευστόχως ευσυνείδητα ευσυνειδήτως
 ευσχήμως ευσχημόνως ευσύνοπτα ευτάκτως ευτελώς ευτράπελα ευτραφώς ευτυχισμένα
 ευτόλμως ευυπολήπτως ευυπόληπτα ευφάνταστα ευφήμως ευφαντάστως ευφημιστικά
 ευφραδώς ευφραντικώς ευφροσύνως ευφρόσυνα ευφυώς ευχάριστα ευχαρίστως
 ευωδερά ευωδιαστά ευόρκως εφάπαξ εφέτος εφήμερα εφαρμοστά εφεδρικά εφεξής
 εφημέρως εφησυχαστικά εφιαλτικά εφιαλτικώς εφιδρωτικώς εφικτά εφορευτικώς
 εφτού εχθές εχθρικά εχθρικώς εχτές εχτός εωθινά εύγλωττα εύθετα εύθετα
 εύθυμα εύκαμπτα εύκολα εύκοσμα εύληπτα εύλογα εύπιστα εύπλαστα εύπορα εύρυθμα
 εύσπλαγχνα εύσπλαχνα εύστοχα εύστροφα εύσχημα εύτολμα εύφημα εύφλεκτα ζαβά
 ζερβόδεξα ζεστά ζευγαρωτά ζευκτά ζηλευτά ζηλιάρικα ζητητικά ζορμπαλίδικα
 ζουρλά ζοχαδιασμένα ζούλα ζυμωτά ζωγραφικά ζωγραφιστά ζωδιακά ζωηρά ζωικά
 ζωολογικά ζωομορφικά ζωοτεχνικά ζωτικά ηγεμονικά ηγετικά ηδέως ηδονικά
 ηδυπαθώς ηθικά ηθικολογικά ηθικοπλαστικά ηθικώς ηθογραφικά ηθογραφικώς
 ηθοπλαστικά ηλίθια ηλεκτρικά ηλεκτρονικά ηλιθιωδώς ηλιοκεντρικά ηλιολατρικά
 ημεδαπά ημερολογιακά ημιδιαφανώς ημικυκλικά ημικυκλικώς ημιτελώς ηπίως
 ηρέμα ηρέμως ηρωικά ηρωικώς ησύχως ηχηρά ηχηρώς ηχητικά ηχητικώς
 θέσει θαλερά θαλπερά θαλπωρικά θαμβά θαμβώς θαμπά θαμπερά θαμπωτικά θανάσιμα
 θανατερά θανατηφόρα θαρραλέα θαρρετά θαυμάσια θαυμαστά θαυματουργά
 θεαματικά θεατράλε θεατρικά θεατρικώς θεατρινίστικα θεληματικά θεληματικώς
 θελκτικώς θεματικά θεμελιακά θεμελιωδώς θεμελιωτικά θεμιτά θεμιτώς θεοειδώς
 θεολογικά θεολογικώς θεοσκότεινα θεοσόφως θεραπευτικά θερινά θερμά θερμικά
 θερμουργώς θεσμικά θεσπέσια θεσπεσίως θετικά θετικιστικά θετικώς θεωρητικά
 θεϊκώς θεόθεν θηλυκά θηλυπρεπώς θηρευτικά θηρευτικώς θηριωδώς θλιβερά θλιβερώς
 θνητά θολά θολερά θολερώς θολοειδώς θολωτά θορυβωδώς θρασέως θρασυδείλως
 θρασύτατα θρεπτικά θρεφτικά θρεψερά θρηνητικά θρηνητικώς θρησκειολογικά
 θρησκευτικώς θριαμβευτικά θριαμβικά θριαμβικώς θυελλωδώς θυμοσοφικά
 θυμωμένα θυσανωτά θωπευτικά θωπευτικώς θωρακωτά θύραθεν ιαματικά ιαπωνικά
 ιατρικά ιγνυακά ιδία ιδίως ιδανικά ιδανικώς ιδεαλιστικά ιδεατά ιδεατώς
 ιδεογραφικώς ιδεοκρατικά ιδεοκρατικώς ιδεοληπτικά ιδεολογικά
 ιδεολογικώς ιδεωδώς ιδιαίτατα ιδιαίτερα ιδιαζόντως ιδιαιτέρως ιδιοβούλως
 ιδιοκτησιακά ιδιορρύθμως ιδιοσυγκρασιακά ιδιοτελώς ιδιοφυώς ιδιοχείρως
 ιδιωτικά ιδιωτικώς ιδιόγραφα ιδιόρρυθμα ιδιότροπα ιδρωτικώς ιεραποστολικά
 ιεραρχικώς ιερατικά ιερογλυφικώς ιεροκρατικώς ιεροκρυφίως ικανά ικανοποιητικά
 ικετευτικά ικετευτικώς ικετικά ικετικώς ιλαρά ιλαρώς ιλιγγιωδώς ιμπεριαλιστικά
 ινιακά ινκόγκνιτο ιουλιανά ιππαστί ιπποδρομιακά ιπποτικά ιπποτικώς ιρανιστί
 ισάκις ισάξια ισάριθμα ισάριθμα ισαξίως ισαρίθμως ισκιερά ισοβίως ισομήκως
 ισοπεδωτικά ισορροπημένα ισορροπημένα ισοσκελώς ισοτίμως ισοταχώς ισοχρονικά
 ισπανικά ισπανιστί ισραηλινά ισραηλιτικά ιστολογικά ιστορικά ιστοριοδιφικά
 ισχνώς ισχυρά ισχυρογνωμόνως ισχυρώς ισόβια ισόρροπα ισόρροπα ισότιμα ισόχρονα
 ιταλιστί ιταμά ιταμώς ιχθυοπαραγωγά ιχνηλατικά ιχνογραφικώς κάθετα κάκιστα
 κάλλια κάλλιο κάλλιστα κάλπικα κάμποσο κάποτε κάπου κάπου κάπου κάπως κάργα
 κάτω κάτωθεν κάτωθι καίρια καβάλα καβαλαρία καβαλικευτά καθάπερ καθέτως καθαρά
 καθαρώς καθαυτού καθαυτό καθεαυτού καθεαυτό καθεξής καθηκόντως καθημερινά
 καθησυχαστικά καθιστά καθιστικά καθολικά καθορισμένα καθορισμένα καθοριστικά
 καθυστερημένα καθωσπρέπει καθόλου καθόσον καθώς καινοφανώς καιρίως
 κακά κακαριστά κακείθεν κακείσε κακεμφάτως κακεντρεχώς κακοήχως κακοζήλως
 κακομόρφως κακοπίστως κακοποιά κακοπροαίρετα κακορίζικα κακόβολα κακόγουστα
 κακόηχα κακόμορφα κακόπιστα κακόσμως κακότεχνα κακόψυχα κακώς καλά καλαίσθητα
 καλαισθητικά καλαισθητικώς καλαματιανά καλαμωτά καληώρα καλικούτσα καλλίτερα
 καλλιγραφικά καλλιγραφικώς καλλιτεχνικά καλοκάγαθα καλοκάρδια καλοκαιριάτικα
 καλολογικά καλοπροαίρετα καλοσυνάτα καλού-κακού καλούτσικα καλπονοθευτικά
 καλόβολα καλόγουστα καλόκαρδα καλότροπα καλότυχα καλύτερα καλώς καμαρωτά
 καμπανιστά καμπουρωτά καμπυλογράμμως καμπυλωτά καμπυλόγραμμα καμπόσο καμωτά
 κανονικά κανονικώς κανταδόρικα καντιανά καπάκι καπηλικώς καπναγωγά καπνιστά
 καραγκούνικα καραφλά καρδιακά καρδιοαγγειακά καρδιογραφικά καρδιογραφικώς
 καρπερά καρποφόρα καρσί καρσινά καρτερικά καρτερικώς καρτεσιανά καρφί καρφωτά
 καστανά κατ'ευθείαν κατάβαθα κατάγναντα κατάκαρδα κατάκλειστα κατάλληλα
 κατάμουτρα κατάντικρυ κατάορτσα κατάπλατα κατάπλωρα κατάπρυμα κατάπτυστα
 κατάστηθα κατάφατσα κατάφωρα κατάχαμα κατέναντι καταή καταγής καταδήλως
 καταδεχτικά καταθλιπτικά καταθλιπτικώς κατακέφαλα κατακαλόκαιρο κατακαμπής
 κατακριτέα κατακτητικά κατακτητικώς κατακόρυφα καταλεπτώς καταληκτικά
 καταληπτά καταληπτικά καταληπτικώς καταλλήλως καταλογάδην καταμεσής κατανάγκη
 καταναγκαστικώς κατανοητά καταντίπ καταντικρύ κατανυκτικά κατανυκτικώς
 καταπάνω καταπίστομα καταπιεστικά καταπιεστικώς καταπληκτικά καταπληκτικώς
 καταποδιαστά καταπονητικά καταπονητικώς καταπραϋντικά καταπραϋντικώς
 καταπτύστως καταπόδας καταπόδι καταπώς καταρρακτωδώς καταρροϊκά καταρχήν
 κατασκοπευτικά κατασκοπευτικώς κατασκότεινα κατασταλαχτά κατασταλτικά
 καταστατικώς καταστρεπτικά καταστρεπτικώς καταστροφικά καταστροφικώς κατασχετά
 καταφανώς καταφατικά καταφατικώς καταφρονητικά καταχθόνια καταχρηστικά
 κατενώπιον κατεξοχήν κατεπειγόντως κατεργάρικα κατεσπευσμένα κατεσπευσμένως
 κατευναστικά κατηγορηματικά κατηγορηματικώς κατηφορικά κατηφορικώς κατηφώς
 κατορθωτά κατσαρά κατσαρωτά κατωτέρω κατωτέρως κατωφερώς κατόπι κατόπιν
 κατώτερα καυστικά καυτά καυτερά καφασωτά καφεϊκά καχεκτικά καχεκτικώς
 καχύποπτα καψαλιστά καψερά κβαντισμένα κει κεκαλυμμένα κεκαλυμμένως
 κελαρυστά κενοδόξως κεντητά κεντρικά κεντρικώς κεντροαριστερά κεντροδεξιά
 κεραμωτά κεραυνοβόλα κερδοφόρως κεφαλαιοκρατικά κεφαλαιωδώς κεφαλληνιακά
 κηδεμονικά κηδεμονικώς κηπευτά κηρωτά κινδυνωδώς κινεζικά κινεζιστί
 κινηματογραφικώς κινητά κινητικά κινητικώς κιρκαδιανά κιτρινωπά κιόλα κιόλας
 κλαδερά κλαδωτά κλαρωτά κλασικά κλασματικά κλασσικά κλαυτά κλαψιάρικα κλειδωτά
 κλειστά κλεφτά κλεφτάτα κληρονομικά κληρονομικώς κληρωτά κλητά κλιμακηδόν
 κλινικά κλιτά κλοτσηδόν κοιλιακά κοιμήσικα κοινά κοινοβιακά κοινοβιακώς
 κοινοβουλευτικώς κοινωνικά κοινωνικοεπαγγελματικά κοινωνικώς κοινωνιοκεντρικά
 κοινότυπα κοινώς κοκκινιστά κοκκινωπά κολάσιμα κολακευτικά κολακευτικώς
 κολλητά κολοβά κολοβώς κολοσσιαία κολοσσιαίως κολπατζίδικα κολποκοιλιακά
 κομματάκι κομματιαστά κομματικά κομματικώς κομπαστικά κομσί κομσά κομψά κομψώς
 κοντακιανά κοντινά κοντολογίς κοντοχωριανά κοπαδιαστά κοπανιστά κοπιαστικά
 κορδωμένα κορδωτά κορεατικά κορινθιακά κοροϊδίστικα κοροϊδευτικά κορυβαντικά
 κοσμικά κοσμοπολίτικα κοσμοπολιτικά κοσμοπολιτκά κοστολογικά κουζουλά
 κουλά κουλουβάχατα κουμπωτά κουνιστά κουρασμένα κουραστικά κουρδιστί κουτά
 κουτρουβάλα κουτσά κουτσά στραβά κουτσομπολίστικα κουτσουμπά κουφά κουφωτά
 κοφτερά κοχλιακά κοχλιωτά κοψοχρονιά κοψοχρονιάς κούτσα κούτσα κούτσα-κούτσα
 κρίσιμα κρανιακά κραταιά κρατερά κραυγαλέα κρεατερά κρεμαστά κρεσέντο κρικωτά
 κριτικά κροκωτά κροσσωτά κρουνηδόν κρουστά κρυερά κρυπτά κρυφά κρυφίως κρυφτά
 κρύφα κρύφια κτηνοτροφικά κτηνοτροφικώς κτηνωδώς κτιριακά κτιστά κτυπητά κυανά
 κυκλικά κυκλικώς κυκλοθυμικά κυκλοθυμικώς κυκλοτερώς κυκλοφοριακά κυκλωτικά
 κυλινδρικώς κυλινδρωτά κυλιστά κυματιστά κυνικά κυνικώς κυπριακά κυρίως
 κυριαρχικά κυριαρχικώς κυριολεκτικά κυριολεκτικώς κυρτά κυρτώς κυφά κωμικά
 κόντρα κύκλωθεν κύρια λάβρα λάβρως λάγνα λάθρα λάου λάου λάργκο λάσκα λέντο
 λίγο λαίμαργα λαγαρά λαδερά λαθεμένα λαθραία λαθραίως λαιμάργως λαμπίκο λαμπρά
 λαμπριάτικα λαμπρώς λανθασμένα λαξ λαξευτά λαργκέτο λατινικά λατινικώς
 λατρευτικά λαϊκά λαϊκίστικα λαϊκιστικά λεβέντικα λεγκάτο λειψά λειψερά λεκτικά
 λεληθότως λεπτά λεπτομερειακά λεπτομερειακώς λεπτομερώς λεπτώς λερά
 λιανά λιανικά λιανικώς λιαστά λιγάκι λιγδερά λιγνά λιγουλάκι λιγουρευτά λιγυρά
 λιθαγωγά λιθουανιστί λικνιστικά λικνιστικώς λιμάρικα λινά λιπαρά λιτά λιτώς
 λογάδην λογικά λοιπά λοξά λοξοειδώς λοξώς λουριδωτά λούτσα λυγερά λυγιστά
 λυπηρά λυπηρώς λυπητερά λυρικά λυρικώς λυσιτελώς λυσσαλέα λυσσαλέως λυσσωδώς
 λωλά λωποδυτικά λωποδυτικώς λόγω μάγκικα μάινα μάλιστα μάλλον μάνι μάνι μάταια
 μέσα μέσω μέτρια μίγδην μίντζα μαγειρικά μαγευτικά μαγικά μαδαρά μαεστόζο μαζί
 μαζοχιστικά μαζωχτά μαθέ μαθές μαθηματικά μαιανδρικά μαιευτικώς μακάρια
 μακιαβελικά μακράν μακριά μακριάθε μακροθύμως μακροκοσμικά μακροπροθέσμως
 μακροσκοπικά μακροσκοπικώς μακρουλά μακροχρόνια μακρόθεν μακρόθυμα μακρύτερα
 μαλακισμένα μαλθακά μαλθακώς μαλλιαρά μαλλωτά μανά μανιακά μανιωδώς μαντάρα
 μαοϊκά μαργιόλικα μαρξιστικά μαρξιστικώς μαρτάπριλα μαρτιάτικα μαρτυρικά
 μασημένα ματαίως μαυριδερά μαχητικά μαχμούρικα μείον μεγάλως μεγαθύμως
 μεγαλεπήβολα μεγαλεπηβόλως μεγαλοβδομαδιάτικα μεγαλοπαρασκευιάτικα
 μεγαλοπρεπώς μεγαλουργά μεγαλοφρόνως μεγαλοφυώς μεγαλοϊδεατικά μεγαλόπρεπα
 μεγαλόψυχα μεθαύριο μεθιλιχίως μεθοδικά μεθοριακά μεθυστικά μεικτά μεικτώς
 μειοδοτικά μειοδοτικώς μειονεκτικά μειονεκτικώς μειωτικά μελαγχολικά
 μελανά μελανωπά μελαχρινά μελετημένα μελετηρά μεληδόν μελιστάλακτα
 μελιχρά μελλοδραματικώς μελλοντικά μελλοντικώς μελοδραματικά μελωδικά μεμιάς
 μενετά μερακλίδικα μεραρχιακά μερικώς μεροληπτικά μεροληπτικώς μερόνυχτα μες
 μεσημεριάτικα μεσημεριανά μεσιακά μεσιανά μεσοβέζικα μεσοβδομαδιάτικα
 μεσογειακά μεσοδρομίς μεσοθάλασσα μεσομακροπρόθεσμα μεσονυχτίς μεσοούρανα
 μεσοπροθέσμως μεσοπρόθεσμα μεσοστρατίς μεσουρανίς μεσοχείμωνα μεσοχρονίς
 μεστά μετά μετέπειτα μεταβατικώς μεταβλητά μεταβυζαντινά μεταγενέστερα
 μεταμεσημβρινά μεταμοντερνιστικά μεταξοπαραγωγά μεταξωτά μεταξύ μεταπλαστά
 μεταπολεμικώς μεταρρυθμιστικώς μεταφερτά μεταφορικά μεταφραστικά μεταφραστικώς
 μετεγχειρητικά μετεκλογικά μετεωροσκοπικώς μετοχικώς μετρίως μετρημένα
 μετριαστικώς μετρικά μετρικώς μετριοπαθώς μετωνυμικά μετωνυμικώς μετωπηδόν
 μεφιστοφελικά μεφιστοφελικώς μηδέποτε μηδαμού μηδαμώς μηδόλως μημειακά
 μητρικώς μητρωνυμικώς μητρόθεν μηχανικά μιαρά μικρά μικροβιακώς
 μικρομετρικά μικροπρεπώς μικροσκοπικά μικτά μισερά μισητά μισητώς μισθωτά
 μισοτιμής μιχτά μνησίκακα μοιραία μοιραστά μοιρολατρικά μοιρολατρικώς μονά
 μονίμως μοναρχικώς μοναστηριακά μοναχά μονοκοπανιά μονοκούκι μονοκόμματα
 μονολεκτικώς μονολεχτικά μονομερίς μονομερίτικα μονομεριάτικα μονομερώς
 μονονουχί μονονυχί μονοπλεύρως μονοπωλιακά μονοπωλιακώς μονορούφι μονοτρόπως
 μοντερνιστικά μονόμπαντα μονόπατα μονόπλευρα μονότερμα μονότονα μονότροπα
 μοραΐτικα μοργανατικώς μοριακά μορφολογικά μορφολογικώς μουγγά μουγκά μουλωχτά
 μουρλά μουσαντά μουσειακά μουσειολογικά μουσειολογικά μουσικά μουσκίδι μουχρά
 μούρλια μούσκεμα μπάρεμ μπάρεμου μπέρδεγουεϊ μπίτι μπαγάσικα μπακαλίστικα
 μπεμπεδίστικα μπερδεμένα μπερκέτι μπηχτά μπιελάρ μπιζ μπιζέ μπιμπιλωτά μπιτ
 μπλιό μποέμικα μπονόρα μπουζάκο μπρος μπροστά μπροστινά μπρούμυτα μπόλικα
 μυθοποιητικά μυριάκις μυριοστά μυσαρά μυσαρώς μυστηριακά μυστηριωδώς μυστικά
 μυτερά μυϊκά μωρά μόλις μόνιμα μόνο μόρτικα νέτα ναζιάρικα ναζιστικά ναι
 νανουριστικά νατουραλιστικά νατοϊκά ναυαγιαιρεσιακά νεανικά νεαρά νεογοτθικά
 νεοελληνιστί νεολατινικά νεορεαλιστικά νεορομαντικά νεοτουρκικά νεοφανώς
 νερουλά νερόβραστα νευρικά νευρογλοιακά νευρολογικά νευρολογικώς νεωστί
 νηπιακά νηπιόθεν νηστίσιμα νηστικάτα νηφάλια νηφαλίως νικηφόρα νικηφόρως
 νοερά νοερώς νοηματικά νοητά νοητικά νομικά νομικώς νομιμοφρόνως νομιναλιστικά
 νομισματολογικώς νομοθετικά νομολογικά νομολογικώς νομοτελειακά νομοτύπως
 νορβηγικά νορμανδικά νοσηρά νοσηρώς νοσοκομειακώς νοσταλγικά νοτίως νοτερά
 νοτινά νοτιοανατολικά νοτιοδυτικά νουνεχώς ντάλα ντίρλα νταμωτά νταντελωτά
 ντε φάκτο ντεκλαρέ ντεκουπαριστά ντεκρεσέντο ντεκρετσέντο ντελόγο ντεμέκ
 ντεψίζικα ντιπ ντογρού ντουγρού ντούκου ντούρου ντούρου ντρέτα ντρίτα ντροπαλά
 ντόμπρα νυκτερινά νυν νυχθημερόν νυχτερινά νυχτιάτικα νυχτοήμερα νωθρά νωθρώς
 νωρίτερα νωχελικά νωχελώς νόμιμα νότια νύκτωρ ξάγναντα ξάπλα ξάστερα ξάφνου
 ξένοιαστα ξέπασχα ξέπνοα ξέσκεπα ξέφρενα ξέχωρα ξανά ξανάστροφα ξαπλωτά
 ξαργιτού ξαργώτου ξαφνικά ξεδιάντροπα ξεκάθαρα ξεκλείδωτα ξεκολλημένα
 ξεκούδουνα ξεκούδουνα ξεκούραστα ξελογιασμένα ξεμυαλισμένα ξενικά ξενικώς
 ξεπίτηδες ξεπιταυτού ξεπιτούτου ξερά ξεστά ξεχωριστά ξεψυχισμένα ξημερώματα
 ξινά ξομπλιαστά ξοπίσω ξυπνά ξυπνητά ξυστά ξώδερμα ξώλαμπρα ξώπασχα ξώπετσα
 ξώφαλτσα ξώφαρσα ξώφαρτσα οία οίκαδε οίκοθεν οίκοι οίον ογδοηκοντάκις
 ογκομετρικώς οδικώς οδοιπορικώς οδοντωτά οδυνηρά οδυνηρώς οικεία οικειοθελώς
 οικιστικά οικογενειακά οικογενειακώς οικολογικά οικονομικά οικοτουριστικά
 οικουρά οικτιρμόνως οικτρά οικτρώς οινολογικά οινολογικώς οινοπαραγωγά οιονεί
 οκλαδόν οκνά οκνηρά οκτάκις ολέθρια ολίγον ολεθρίως ολημέρα ολημερίς ολιγάκις
 ολιγοστά ολικά ολλανδικά ολλανδιστί ολοένα ολοήμερα ολογράφως ολογραφικώς
 ολοκάθαρα ολοκληρωμένα ολοκληρωτικά ολοκληρωτικώς ολονέν ολονυχτίς ολοπρόθυμα
 ολοστρόγγυλα ολοσχερώς ολοταχώς ολοτρόγυρα ολοφάνερα ολοχρονίς ολοψύχως ολούθε
 ολόγυρα ολόθεν ολόθερμα ολόιδια ολόισα ολόισια ολότελα ολόχαρα ολόψυχα ομάδι
 ομαδικώς ομαδόν ομαλά ομαλώς ομιλητικά ομιλητικώς ομοίως ομοειδώς ομοθυμαδόν
 ομοιογενώς ομοιομερώς ομοιομόρφως ομοιοπαθώς ομοιοπτώτως ομοιοτρόπως
 ομοιόπτωτα ομοιότροπα ομοκέντρως ομοκεντρικώς ομολογητικώς ομολογιακά
 ομοουσίως ομοσκεδαστικά ομοσπονδιακά ομοσπονδιακώς ομοτόνως ομοφήφως ομοφοβικά
 ομού ομπρός ομφαλωτά ομόθυμα ομόκεντρα ομόφωνα ομόψυχα ονειρεμένα ονειρευτά
 ονειρωδώς ονομαστί ονοματολογικώς οντολογικά οντολογικώς ονόματι οξέως
 οξύθυμα οπίσω οπισθάγκωνα οπισθοβατικώς οπισθοδρομικά οπισθοδρομικώς
 οποσάκις οποτεδήποτε οπουδήποτε οπτικώς οπωσδήποτε οπωσούν οπόθεν ορατά
 ορατώς οργίλως οργανικά οργανικώς οργανωμένα οργιαστικώς οργισμένα ορεινά ορθά
 ορθίως ορθογραφικώς ορθογωνίως ορθοεπώς ορθολογικά ορθολογικώς ορθομετρικά
 ορθοπαιδικώς ορθοπεδικώς ορθρινά ορθώς οριακά οριζοντίως οριζόντια ορισμένως
 οριστικώς ορκωτά ορμέμφυτα ορμεμφύτως ορμητικά ορμητικώς οροθοπεδικά ορτά
 ορυκτολογικώς ορφνά οσάκις οσίως οσημέραι οσμηρά οσοδήποτε οσονούπω οσφυϊκά
 οτρηρά ου ουδέποτε ουδέτερα ουδαμού ουδαμόθεν ουδαμώς ουδετέρως ουδόλως ουκ
 ουκρανικά ουμανιστικά ουρανόθεν ουσιαστικά ουσιαστικώς ουσιωδώς ουτιδανά
 ουτοπικώς οφέτος οφθαλμοσκοπικώς οφλάιν οχλαγωγικώς οχληρά οχληρώς
 οχτωβριανά οχυρά οψάργας οψέ οψέποτε οψές οψίμως οψαργάς ούθεν ούτω ούτως
 πάλαι πάλε πάλι πάλιν πάμφθηνα πάνου πάντα πάντοτε πάντοτες πάντως πάνυ πάνω
 πάρωρα πάτα κιούτα πάτσι πένθιμα πέρα πέραν πέριξ πέρσι πέρυσι πήχτρα πίστομα
 πίσωθε πίτσι πίτσι παγίως παγερά παγκάλως παγκοίνως παγκοσμίως παγκουί
 παθητικά παθιασμένα παθολογικά παιγνιωδώς παιδαγωγικά παιδαριωδώς παιδευτικά
 παιδικά παιδικώς παιδιόθεν παιδοκομικά παλαβά παλαιά παλαιογραφικώς
 παλαιόθεν παλαιότερα παλιά παλικαρίσια παλινδρομικά παλινδρομικώς παλινορθώ
 παλμικώς παμψηφεί πανάκριβα πανδημεί πανελλαδικά πανελλαδικώς πανευτυχώς
 πανηγυρικώς πανθεϊστικά πανθεϊστικώς πανθομολογουμένως πανοικεί πανοραματικά
 πανοραμικά πανοραμικώς πανστρατιά παντάπασι παντάπασιν πανταχού πανταχόθεν
 παντοίως παντοειδώς παντοιοτρόπως παντοτινά παντοτινώς παντού παπαγαλιστί
 παράδοξα παράκαιρα παράλληλα παράλογα παράμερα παράνομα παράξενα παράπαν
 παράτυπα παράφορα παράφωνα παράωρα παρέα παρέκει παραέξω παραΰστερα παραβολικά
 παραγωγικά παραγωγικώς παραδειγματικά παραδειγματικώς παραδεισιακά
 παραδεκτά παραδεχτά παραδοσιακά παραδόξως παραδώ παραδώθε παραεκκλησιαστικά
 παραινετικώς παρακάτω παρακαίρως παρακαλεστά παρακαλεστικά παρακαλετά
 παρακεί παρακινδυνευτικά παρακινδυνευτικώς παρακινητικά παρακινητικώς
 παρακλητικά παρακμιακά παραλίγο παραλιακά παραλλήλως παραλόγως παραμάζωμα
 παραμάσχαλα παραμέσα παραμεθαύριο παραμεσημβρινά παραμικρά παραμορφωτικά
 παρανιά παρανοϊκά παρανόμως παραπάνω παραπέρα παραπίσω παραπανιστά
 παραπλανημένα παραπλανητικά παραπλεύρως παραπονιάρικα παρασιτικά παρασιτικώς
 παρασκηνιακώς παραστατικά παραστατικώς παρατεταγμένα παρατεταμένα παρατηρητικά
 παρατόλμως παραφιλικά παραφραστικά παραφραστικώς παραφόρως παραφύση παραφώνως
 παρδαλά παρειακά παρελκυστικά παρεμπιπτόντως παρεμπρός παρεμφερώς παρενθετικώς
 παρετυμολογικά παρετυμολογικώς παρευθύς παρηγορητικά παρθενικώς παρθενωπά
 παρισινά παρλιακά παρνασσιακά παροδικά παροδικώς παροιμιακώς παροιμιωδώς
 παρτσακλά παρόμοια πασαλίδικα πασιδήλως πασιφανώς πασπατευτά παστά παστρικά
 πασχαλινά πατ κιουτ παταγωδώς πατητά πατρικώς πατρινά πατριωτικά πατριωτικώς
 πατόκορφα πατόκωλα παχουλά παχυλά παχυλώς πεζά πεζή πεζοδρομιακά πειθήνια
 πειθαρχικώς πειθηνίως πεινασμένα πειρακτικά πειρατικώς πειραχτικά πεισματικά
 πεισματωδώς πειστικά πειστικώς πελεκητά πελελά πελιδνά πενιχρά πενιχρώς
 πεντάκις πεντακοσιοστά πενταμερώς πενταπλά πενταπλάσια περήφανα περίγυρα
 περίκαλα περίλαμπρα περίπου περίφημα περαιτέρω περαστά περιέργως περιαιρετά
 περιγραφικά περιγραφικώς περιδεώς περιεκτικά περιεκτικώς περιεσκεμμένως
 περικαρπιακά περιλάμπρως περιληπτικά περιληπτικώς περιμετρικά περιμετρικώς
 περιορισμένα περιοριστικά περιοριστικώς περιοστεϊκά περιουσιακά περιπαθώς
 περιπαιχτικά περιπατητικά περισκοπικά περισπουδάστως περισσά περισσότερο
 περισταλτικώς περιστασιακά περιστασιακώς περιστροφικά περιστροφικώς
 περιττά περιττώς περιφερειακά περιφερικά περιφραστικά περιφρονητικά περιχυτά
 περσικά περσινά περσιστί περσοειδώς περυσινά πεσιμιστικά πεσιμιστικώς πεταχτά
 πετρελαιοπαραγωγά πετρωτά πετυχημένα πηγαία πηδηχτά πηκτά πηρά πηχτά πιάνο πια
 πιανιστικά πιεστά πιεστικά πιθανά πιθανόν πιθανότατα πιθανώς πικρά πικρώς
 πιο πιπιλιστά πισθάγκωνα πιστά πιστάγκωνα πιστευτά πιστότερα πισωκάπουλα
 πισώπλατα πιτς φιτίλι πιτσιλιστά πιότερο πλάγια πλάι πλάτσα πλούτσα πλέον
 πλήρως πλαγίως πλαγιαστά πλαδαρά πλακουτσωτά πλακωτά πλανερά πλασαριστά
 πλασμωδιακά πλαστά πλαστικά πλατέως πλατιά πλατωνικά πλαϊνά πλειστάκις πλεκτά
 πλεονεκτικώς πλευρικώς πλευρόθεν πλευστά πλεχτά πληθικώς πληθυσμιακά πληκτικά
 πληρέστερα πληροφοριακά πληροφοριακώς πλησίον πλησιέστερα πληχτικά πλια πλιο
 πλουμιστά πλουσίως πλουσιοπάροχα πλουσιοπαρόχως πλουτοκρατικώς πλοϊκά πλούσια
 πλώρα πνευματικώς πνευματωδώς πνευστά πνιγερά πνιχτά ποδαράτα ποθές ποιητικά
 ποικιλομόρφως ποικιλοσχήμως ποικιλοτρόπως ποικιλόμορφα ποιμαντορικώς ποινικώς
 πολεμικώς πολιτειακά πολιτικά πολιτικοστοχαστικά πολιτικοστρατηγικά πολιτικώς
 πολιτιστικά πολιτιστικώς πολλά πολλάκις πολλαπλά πολλαπλάσια πολλαπλώς
 πολλαχόθεν πολλαχώς πολληώρα πολλοστά πολυέξοδα πολυγραφικώς πολυειδώς
 πολυκερδώς πολυμορφικά πολυμόρφως πολυπλόκως πολυπροσώπως πολυσυλλάβως
 πολυτίμως πολυτελώς πολυτρόπως πολυφωνικά πολωνιστί πολύ πολύμορφα πολύπλοκα
 πομπωδώς πονηρά ποντιακά πονόψυχα πορνικώς πορτογαλικά πορτογαλιστί πορφυρά
 ποσοστιαία ποσοστικά ποσοτικά ποσοτικώς ποστρεστάντ ποσώς ποτέ ποτές ποταμηδόν
 ποταπώς πουθενά πουρά πουριτανικά πουτανίστικα πού πούθε πούθεν πούπετα
 πράγματι πράως πραγματικά πραγματικώς πραιτοριανά πρακτικά πρακτικώς
 πραξικοπηματικώς πρασινωπά πραχτικά πραϋντικά πραϋντικώς πρεπόντως πρεσβυτικώς
 πριγκιπικά πριν πριονιστά πριονωτά πρισματικά πριχού προ παντός προαγωγικά
 προαιρετικά προαιρετικώς προαστιακά προβηγκιανά προβλεπτικά προβληματικά
 προγενέστερα προγενεστέρως προγραμματικά προγραμματικώς προγραμματισμένα
 προδοτικά προδοτικώς προειδοποιητικά προεισαγωγικώς προεκλογικά
 προεξοφλητικώς προεσκεμμένως προηγουμένως προηγούμενα προκαταβολικά
 προκαταρκτικά προκαταρκτικώς προκλητικά προκλητικώς προκολομβιανά προλεταριακά
 προληπτικώς προμελετημένα προμεσημβρινά προνοητικώς προνομιακά προνομιακώς
 προοδευτικώς προοιμιακά προοπτικώς προορατικώς προπάντων προπέρσι προπέρυσι
 προπαντός προπαρασκευαστικώς προπερσινά προπερυσινά προπολεμικά προπολεμικώς
 προσβλητικά προσβλητικώς προσεγγιστικά προσεκτικά προσεκτικώς προσεχτικά
 προσηκόντως προσηλιακά προσηλωμένα προσθέτως προσθετά προσιτά προσκαίρως
 προσποιητά προσποιητώς προστακτικώς προσταχτικά προσφάτως προσφιλώς προσφυώς
 προσχηματικώς προσωδιακά προσωδιακώς προσωπικά προσωπικώς προσωρινά προσωρινώς
 προτελευταία προτελευταίως προτιμότερα προτιμότερο προτιμότερον προτρεπτικά
 προτροπάδην προφαντά προφανώς προφητικά προφορικά προφορικώς προφυλακτικά
 προφυλαχτικά προχείρως προχθές προχτές προχωρητικώς προψές προϊστορικά
 προύμυτα προώρως πρυμιά πρυμνιά πρωί πρωίμως πρωθυστέρως πρωθύστερα πρωινά
 πρωρατικά πρωτίστως πρωταπριλιάτικα πρωταρχικά πρωτεϊκά πρωτινά πρωτογενώς
 πρωτοκορινθιακά πρωτομαγιάτικα πρωτομαρτιάτικα πρωτοποριακά πρωτοσέλιδα
 πρωτουργά πρωτοχρονιάτικα πρωτυτερινά πρωτόγονα πρωτότυπα πρωτύτερα πρόδηλα
 πρόμυτα πρόπερσι πρόσθεν πρόσκαιρα πρόστυχα πρόσφατα πρόσχαρα πρόσω πρότερον
 πρόχειρα πρόωρα πρύμα πρύμνηθεν πρώιμα πρώραθεν πρώτα πρώτιστα πρώτον πτερωτά
 πτυχωτά πτωτικά πτωχά πυκνά πυκνώς πυξ πυορροϊκά πυραμιδωτά πυργωτά πυρετωδώς
 πόθεν πόμπα πόρρω πόρρωθεν πόσο πότε πότε πότε πώς ράγδην ράθυμα ραβδοσκοπικά
 ραγδαία ραγδαίως ραγιάδικα ραδιενεργά ραδιολογικά ραδιοσκοπικά
 ραδιοτηλεοπτικά ραδιοτηλεφωνικά ραδιοτηλεφωνικώς ραδιοφωνικά ραθύμως ραιβά
 ρασιοναλιστικά ρατσιστικά ρεαλιστικά ρεβανσιστικά ρευματολογικά ρευστά
 ρητά ρητορικά ρητώς ριγηλά ριγωτά ριζικά ριζοσπαστικά ριζοσπαστικώς ρινολογικά
 ριταρντάντο ριχτά ριψοκίνδυνα ροδαλά ροδιακά ρομαντικά ρομβωτά ροταριανά
 ρουμανιστί ρουμελιώτικα ρουφηχτά ροφητά ρυθμικά ρυθμικώς ρυπαντικά ρυπαντικώς
 ρωμαλέως ρωμαϊστί ρωσικά ρωσιστί σάματι σάμπως σήμερα σίγουρα σαββατιάτικα
 σαγηνευτικά σαγηνευτικώς σαδομαζοχιστικά σαθρά σανιδωτά σανφασόν σαπρά
 σαρδόνια σαρκαστικά σαρκαστικώς σαρκικά σαρκικώς σατανικά σατανικώς σατράπικα
 σατραπικώς σαφέστερα σαφώς σαχλά σβέλτα σβηστά σβουριχτά σγουρά σειστά
 σελωτά σεμιναριακά σεμνά σεξουαλικώς σεπτά σερί σερβικά σερβιστί σηκωτά
 σημαδιακά σημαντικά σημαντικώς σημασιολογικά σημασιολογικώς σθεναρά σθεναρώς
 σιγαλά σιγαλόφωνα σιγανά σιγηλά σιγηλώς σιδηροδρομικώς σικάτα σιμά σιμοτινά
 σιταγωγά σιτευτά σιτοπαραγωγά σιχαμερά σιχτά σιωπηλά σιωπηλώς σιωπηρά σιωπηρώς
 σκέτα σκέτα σκαιά σκαιώς σκαλιστά σκαλωτά σκανδαλιάρικα σκανδαλοπλόκως
 σκανδαλωδώς σκανταλιάρικα σκαπτά σκαρφαλωτά σκαστά σκαυϊκά σκαφιδωτά σκαφτά
 σκεπαστά σκεπτικά σκεπτικώς σκερτσάντο σκερτσόζικα σκευαγωγά σκεφτικά σκηνικά
 σκιαγραφικώς σκιερά σκιστά σκλαβωμένα σκληρά σκληρώς σκολιανά σκοπίμως
 σκοταδερά σκοτεινά σκοτικά σκοτσέζικα σκυθρωπά σκυρωτά σκυφτά σκωπτικά σκωτικά
 σκωτσέζικα σκόπιμα σκόρπια σλοβακικά σμικρά σμιλευτά σμιχτά σνομπιστικά σοβαρά
 σοβινιστικά σοβράνο σομφά σοστενούτο σουβλερά σουβλιστά σουηδικά σουρεαλιστικά
 σουσαμωτά σοφά σοφιστικώς σοφράν σοφράνο σοφώς σούρουπα σπάνια σπάταλα
 σπαθωτά σπανά σπανίως σπανιότατα σπανιότερα σπαραχτικά σπαρτά σπαρταριστά
 σπαστικά σπειρωτά σπερματαγωγά σπερματορροϊκά σπερνά σπλαγχνικά σπλαχνικά
 σπονδειακά σποράδην σποραδικά σποραδικώς σπουδαία σπουδαίως σπυρωτά σπόρκα
 στάσιμα σταβέντο σταβέτ σταδιακά σταδιακώς σταθερά σταθεροποιητικά σταθερώς
 στακτά σταλαχτά σταλινικά σταμπωτά στανικώς σταράτα στατικά στατικώς
 στατιστικώς σταυροειδώς σταυροπηγιακά σταυροπόδι σταυρωτά σταχτερά στεγανά
 στεγνά στενά στενάχωρα στενογραφικά στενογραφικώς στεντορείως στεντόρεια
 στερεά στερεοτύπως στερεοφωνικά στεριανά στερνά στερρά στερρώς στεφανωτά
 στητά στιβαρά στιβαρώς στιγμιαία στιγμιαίως στικτά στιλπνά στιφρά στιφτά
 στιχηρά στιχουργικά στοίβα στοιβαχτά στοιχειακά στοιχειωδώς στοιχηδόν στοργικά
 στουμπουλά στοχαστικά στοχαστικώς στράφι στραβά στραγγιστά στραγγιχτά
 στρατηγικώς στρατοκρατικώς στρεβλά στρεπτά στρεψόδικα στριγκά στριμωχτά
 στριφτά στρογγυλά στρυφνά στρωτά στρόγγυλα στυγερά στυγερώς στυγνά στυγνώς
 στυφούτσικα στωικά συγγνωστά συγκαιρινά συγκαταβατικά συγκαταβατικώς
 συγκεκριμένα συγκεκριμένως συγκεντρωμένα συγκεντρωτικά συγκεντρωτικώς
 συγκεχυμένως συγκινησιακά συγκινητικά συγκινητικώς συγκλονιστικά
 συγκοινωνιακά συγκρατημένα συγκριτικά συγκριτικώς συγκυριακά συγχρονισμένα
 συγχωριανά συθέμελα συκοφαντικά συλλήβδην συλλαβιστά συλλογικά συμβασιουχικά
 συμβατικά συμβατικώς συμβιβαστικά συμβιωτικά συμβολαιογραφικά συμβολικά
 συμμέτρως συμμίγδην συμμετρικά συμμετρικώς συμπαγώς συμπαθητικά συμπαθώς
 συμπερασματικώς συμπιεστά συμπιεστικώς συμπλεχτικά συμπληρωματικά
 συμπολιτειακά συμποσιακά συμπτωματικά συμπτωματικώς συμπτωματολογικώς
 συμφιλιωτικά συμφορητικά συμφυώς συμφωνικώς συμφώνως συμψηφιστικώς συνάμα
 συνήθως συναγωνιστικά συναδελφικά συναδελφικώς συναινετικά συναισθηματικά
 συνακολούθως συνακόλουθα συναμεταξύ συναπτά συναρπαστικά συναρπαστικώς συναφώς
 συνδυαστικώς συνειδησιακά συνειδητά συνειδητώς συνειρμικά συνειρμικώς
 συνεκτικώς συνεπίκουρα συνεπώς συνεσταλμένα συνετά συνεταιρικώς συνετώς
 συνεχώς συνηθέστερα συνημμένα συνημμένως συνθετικώς συνθηματικά συνθηματικώς
 συννόμως συνοδεία συνοικιακά συνολικά συνολικώς συνομοσπονδιακά συνοπτικά
 συνοριακά συνταγματικά συνταγματικώς συντακτικώς συνταραχτικά συντεταγμένα
 συντηρητικά συντηρητικώς συντομογραφικά συντομογραφικώς συντονισμένα
 συντροφιαστά συντροφικά συντροφικώς συντόμως συνωδά συνωμοτικά συνωμοτικώς
 συριακά συριανά συρτά συστάδην συσταλτά συστηματικά συστηματικώς συστολικά
 συχνάκις συχνότερα συχωριανά σφαιρικά σφαλερά σφαλερώς σφαλιστά σφαχτά
 σφιχτά σφοδρά σφοδρώς σφορτσάντο σφουγγαρισμένα σφραγιστά σφριγηλά σφυριχτά
 σχεδόν σχετικά σχετικιστικά σχετικιστικώς σχετικώς σχετλιαστικά σχηματικά
 σχιζοφρενικά σχιστά σχοινοτενώς σχολαστικά σχολαστικώς σωληνωτά σωματειακά
 σωματικώς σωματολογικά σωματολογικώς σωρευτικά σωρηδόν σωριαστά σωστά σωστικά
 σωφρόνως σόλο σύγκαιρα σύγκορμα σύγχρονα σύμμετρα σύμφωνα σύμφωνοι σύναυγα
 σύνθετα σύννομα σύνταχα σύντομα σύρριζα τ' αψήλου τάβλα τάτσι μίτσι κότσι τάχα
 τάχατε τάχατες τέζα τέλεια τέντα τήδε τίγαρις τίγκα τίμια ταινιωτά ταιριαστά
 τακτικά τακτικιστικά τακτικότερα τακτικώς τακτοποιημένα ταμάμ ταμειακά ταμιακά
 ταμιευτικώς ταμπλ ντοτ τανάπαλιν ταξικά ταξινομικά ταπί ταπεινά ταπεινωτικά
 ταπεινώς ταραγμένα ταραχοποιά ταριχευτά ταρτάρ ταυτοχρόνως ταυτόχρονα ταχέως
 ταχινά ταχτικά ταχυδακτυλουργικά ταχυδακτυλουργικώς ταχυεργά ταχυμετρικώς
 ταχύ ταχύτερα τεζαριστά τεκμαρτά τεκμηριωμένα τελείως τελειωτικά τελειωτικώς
 τελεσίδικα τελεσιγραφικά τελεσιγραφικώς τελεσιδίκως τελετουργικά τελευταία
 τελικά τελικώς τελολογικά τελωνειακά τεμαχηδόν τεμπέλικα τενούτο τεντωτά
 τεραστίως τερατωδώς τερπνά τερπνώς τεσσαρακοντάκις τεσσαρακονταπλασίως
 τετ-α-τετ τετράκις τετραγωνικά τετραγωνικώς τετρακοσιοστά τετραπλά τετραπλάσια
 τετραχόθεν τεφρά τεχνηέντως τεχνητά τεχνητώς τεχνικά τεχνικώς τεχνολογικά
 τζαμπέ τζαμωτά τζιτζί τηγανητά τηγανιστά τηλεγραφικά τηλεγραφικώς τηλεοπτικά
 τηλεσκοπικά τηλεσκοπικώς τηλεφωνικά τηλεφωνικώς τηνιακά τιμίως τιμαριθμικά
 τιμητικά τιμητικώς τμηματικά τμητά τοιουτοτρόπως τολμηρά τολμηρώς τοξοειδώς
 τοπικά τοπικιστικά τοπικιστικώς τοπικώς τοπογραφικώς τορευτά τορνευτά τοσάκις
 του χρόνου τουλάχιστο τουλάχιστον τουναντίον τουριστικά τουρκικά τουρκιστί
 τουσέ τουφωτά τούμπαλιν τούρκικα τούρλα τρέλα τρίσβαθα τραβηχτά τραγανά
 τραγικά τραγουδιστά τραγουδιστικά τρανά τρανταχτά τρανώς τραυλά τραχέως
 τραχιά τρελά τρεμολάντο τρεμουλιαστά τρεχάλα τρεχάτα τριακοντάκις τριακοσιοστά
 τριγυρινά τριγύρα τριγύρω τρικούβερτα τρικυμιωδώς τριπλά τριπλάσια τριπλασίως
 τριτογενώς τριτοκοσμικά τριτοπροσώπως τριφτά τριχωτά τρομακτικά τρομακτικώς
 τρομερά τρομερώς τρομοκρατικά τρομοκρατικώς τρουλωτά τροφαντά τροχάδην
 τροχιοδρομικώς τρυπητά τρυφερά τρυφερώς τρυφηλά τρυφηλώς τρωίρο τρωτά τσάμπα
 τσίμα τσίμα τσίφτικα τσαγανά τσαγκά τσακιστά τσακωτά τσαπατσούλικα τσεβδά
 τσιγαριστά τσιγγούνικα τσιγκούνικα τσικ του τσικ τσιριχτά τσιτσίδι τσιτωτά
 τυλιχτά τυπικά τυπικώς τυπολατρικά τυραννικά τυραννικώς τυφλά τυφλώς τυχαία
 τυχερά τυχοδιωκτικά τυχοδιωχτικά τυχόν τωρινά τωόντι τόσο τότε τότες τύποις
 τώρα υβρεοφοβικά υβριστικά υβριστικώς υγιεινά υγιεινώς υγιώς υδατοστεγώς
 υδροσκοπικά υδροστατικά υλιστικά υλιστικώς υμνητικά υπάκουα υπέργεια υπέρμετρα
 υπέροχα υπέρτατα υπήνεμα υπαίθρια υπαιθρίως υπαινικτικά υπαρκτά υπαρξιακά
 υπεγγύως υπεράγαν υπεράνθρωπα υπεράνω υπερήφανα υπεραπλουστευτικά υπεραρκετά
 υπερβατά υπερβατικά υπερβολικά υπερβολικώς υπεργείως υπερθετικά υπερμέτρως
 υπεροπτικώς υπερπολυτελώς υπερπροστατευτικά υπερρεαλιστικά υπερτροφικά
 υπερφιάλως υπερφυσικά υπερφωτοταχυντικά υπερόγκως υπερόχως υπευθύνως υπεύθυνα
 υπηρεσιακά υπηρετικά υπηρετικώς υποβλητικά υποβλητικώς υποβοηθητικά
 υποβολιμαίως υποβρυχίως υποβρύχια υπογείως υποδεέστερα υποδεεστέρως
 υποδειγματικώς υποδορίως υποδόρια υποθετικά υποθετικώς υποκάτω υποκειμενικά
 υποκοριστικά υποκοριστικώς υποκριτικά υποκριτικώς υποκώφως υπολογιστικά
 υπομνηματικά υπομνηστικά υπομονετικά υπομονητικά υπομονητικώς υπονομευτικά
 υποστασιακά υποστυλωτικά υποσυνείδητα υποσυνείδητα υποσυνειδήτως υποταγμένα
 υποτονικά υποτυπωδώς υποφερτά υποφωτοταχυντικά υποχονδριακά υποχοντριακά
 υποχωρητικά υποχωρητικώς υποχόνδρια υπούλως υπτίως υπόγεια υπόκωφα υπόλευκα
 υπόψη υπόψιν υστερικά υστερινά υστερνά υστεροβούλως υστεροβυζαντινά
 υστερόβουλα υφαντά υψηλά υψηλοφώνως υψηλόφωνα υψιτενώς υψομετρικά υψομετρικώς
 φάτσα φέτος φίλα φίνα φαιδρά φαινομενικά φαινομενικώς φαινομενολογικά
 φαλλοκρατικά φαλτσαριστά φανατικά φανατικώς φανερά φανερώς φαντασιακά
 φανταστικά φανταστικώς φανταχτά φανταχτερά φαντεζί φαρισαϊκά φαρισαϊκώς
 φαρμακοδυναμικά φαρμακοκινητικά φαρσί φασιστικά φατικά φατνωτά φατριακά
 φατριαστικώς φατσικά φαφούτικα φαύλα φειδωλά φελιαστά φεμινιστικά φεουδαρχικώς
 φευγαλέα φευκτά φθηνά φθηνούτσικα φθινοπωρινά φθογγογραφικά φθονερά φθονερώς
 φιλάνθρωπα φιλανθρωπικά φιλειρηνικά φιλελληνικά φιλεύσπλαγχνα φιλεύσπλαχνα
 φιλικότατα φιλοαγροτικά φιλοζωικά φιλολογικά φιλολογικώς φιλοπόλεμα
 φιλοσοφημένα φιλοσοφικά φιλοσοφικώς φιλοστόργως φιλοτέχνως φιλοφρονητικά
 φιλόδοξα φιλόξενα φιλόστοργα φινλανδικά φιρί φιρί φλαμανδικά φλεβαριάτικα
 φλογερά φλογερῶς φλοκιαστά φλοκωτά φλουδερά φλύαρα φοβερά φοβερώς φοβισμένα
 φορμαλιστικά φορμαλιστικώς φορμαρισμένα φορολογικά φορολογικώς φορτικά
 φορτσαριστά φουλ φουλαριστά φουντωτά φουριόζικα φουριόζο φουσκωτά
 φράγκικα φραγκοδίφραγκα φραξιονιστικά φραστικά φραστικώς φρενιασμένα
 φρικτά φρικτώς φρικωδώς φριχτά φρονίμως φρονηματιστικά φρονηματιστικώς
 φρουριακά φρυκτά φρόνιμα φτενά φτερωτά φτηνά φτηνούτσικα φτιαστά φτιαχτά
 φτωχά φτωχικά φυγοκεντρικά φυλετικά φυρί φυρί φυσητά φυσικά φυσικώς
 φυσιογνωμικώς φυσιοθεραπευτικά φυσιολογικά φυσιολογικώς φυτευτά φωναχτά
 φωνομετρικά φωτερά φωτογραφικώς φωτομετρικά φωτοτυπικά φωτοχημικά φύρδην
 φύσει χάλια χάμου χάμω χάρμα χάσκα χίπικα χαβαλέ χαζά χαιρέκακα χαιρεκάκως
 χαλαρά χαλαρωτικά χαλεπώς χαλικωτά χαμαί χαμερπώς χαμηλά χαμηλοφώνως
 χαμηλότερα χαμηλόφωνα χαμηλώς χαμογελαστά χαοτικά χαράμι χαρακτηριστικά
 χαριστικά χαριστικώς χαριτωμένα χαρούμενα χαρωπά χατιρικά χατιρικώς χαϊδευτικά
 χειριδωτά χειροπόδαρα χειρουργικά χειρωνακτικά χειρωνακτικώς χειρότερα
 χεροπόδαρα χημικά χθαμαλά χθες χιαστά χιαστί χιλιάκις χιλιαπλάσια χιλιαπλασίως
 χινοπωριάτικα χιουμοριστικά χιτλερικά χλευαστικά χλευαστικώς χλιαρά χλιαρώς
 χλωμά χολιγουντιανά χονδρά χονδρικά χονδρικώς χονδροειδώς χοντρά χοντρικά
 χορειακά χορευτά χορευτικά χορωδιακά χουχουλιάρικα χρήσιμα χρηματιστηριακώς
 χρηματοοικονομικά χρησίμως χρησιμοθηρικά χρηστά χριστά χριστιανικά
 χριστουγεννιάτικα χριστούγεννα χρονίως χρονικώς χρονογραφικά χρονογραφικώς
 χρονομετρικά χρονομετρικώς χρωματικά χρωματικώς χρωματιστά χρωμολιθογραφικά
 χτεσινοβραδινά χτιστά χυδαία χυδαίως χυδαϊστί χωνευτικά χωριάτικα χωριστά
 χωροταξικά χύδην χύμα χώρια ψαθυρά ψαλιδιστά ψαλιδωτά ψαλμικά ψαλτά ψαρωτικά
 ψαχουλευτά ψεκτά ψες ψευδά ψευδαισθητικά ψευδωνύμως ψευδώνυμα ψευδώς
 ψευτοϊδεαλιστικά ψεύτικα ψηλά ψηλαφητά ψηλαφητί ψηλαφιστά ψηλοκρεμαστά
 ψηφιακά ψιθυριστά ψιλά ψιλωτικά ψιχαλιστά ψυκτικά ψυχαγωγικά ψυχαναλυτικά
 ψυχικά ψυχογραφικά ψυχοδραματικά ψυχοκοινωνιολογικά ψυχολογικά ψυχομετρικά
 ψυχοπνευματικά ψυχοτεχνικά ψυχοφυσικά ψυχοφυσικώς ψυχοφυσιολογικώς ψυχρά
 ψυχραντικά ψωροπερήφανα ψόφια ψύχραιμα ωδικώς ωμά ωρίμως ωραία ωραιότατα
 ωριαία ωριαίως ως ωσαύτως ωσεί ωφέλιμα ωφελίμως ωφελιμιστικά ωχρά όθε όθεν όλο
 όμορφα όντως όξω όπισθεν όπου όπως όρθια όρτσα όσια όσο όχι όψιμα ύπερθεν
""".split())



# coding: utf8
from __future__ import unicode_literals

from .tokenizer_exceptions import TOKENIZER_EXCEPTIONS
from .punctuation import TOKENIZER_PREFIXES, TOKENIZER_SUFFIXES, TOKENIZER_INFIXES
from .tag_map import TAG_MAP
from .stop_words import STOP_WORDS
from .lemmatizer import LEMMA_RULES

from ..tokenizer_exceptions import BASE_EXCEPTIONS
from ...language import Language
from ...attrs import LANG
from ...util import update_exc


class BengaliDefaults(Language.Defaults):
    lex_attr_getters = dict(Language.Defaults.lex_attr_getters)
    lex_attr_getters[LANG] = lambda text: 'bn'
    tokenizer_exceptions = update_exc(BASE_EXCEPTIONS, TOKENIZER_EXCEPTIONS)
    tag_map = TAG_MAP
    stop_words = STOP_WORDS
    lemma_rules = LEMMA_RULES
    prefixes = TOKENIZER_PREFIXES
    suffixes = TOKENIZER_SUFFIXES
    infixes = TOKENIZER_INFIXES


class Bengali(Language):
    lang = 'bn'
    Defaults = BengaliDefaults


__all__ = ['Bengali']



# coding: utf8
from __future__ import unicode_literals


from ..tokenizer_exceptions import BASE_EXCEPTIONS
from ..norm_exceptions import BASE_NORMS
from ...language import Language
from ...attrs import LANG, NORM
from ...util import update_exc, add_lookups


class MultiLanguageDefaults(Language.Defaults):
    lex_attr_getters = dict(Language.Defaults.lex_attr_getters)
    lex_attr_getters[LANG] = lambda text: 'xx'
    lex_attr_getters[NORM] = add_lookups(Language.Defaults.lex_attr_getters[NORM], BASE_NORMS)
    tokenizer_exceptions = update_exc(BASE_EXCEPTIONS)


class MultiLanguage(Language):
    """Language class to be used for models that support multiple languages.
    This module allows models to specify their language ID as 'xx'.
    """
    lang = 'xx'
    Defaults = MultiLanguageDefaults


__all__ = ['MultiLanguage']



# coding: utf8
from __future__ import unicode_literals

# import symbols – if you need to use more, add them here
from ...symbols import ORTH, LEMMA, TAG, NORM, ADP, DET

# Add tokenizer exceptions
# Documentation: https://spacy.io/docs/usage/adding-languages#tokenizer-exceptions
# Feel free to use custom logic to generate repetitive exceptions more efficiently.
# If an exception is split into more than one token, the ORTH values combined always
# need to match the original string.

# Exceptions should be added in the following format:

_exc = {

}

# To keep things clean and readable, it's recommended to only declare the
# TOKENIZER_EXCEPTIONS at the bottom:

TOKENIZER_EXCEPTIONS = _exc



# coding: utf8
from __future__ import unicode_literals

import sys
import ujson
import itertools
import locale

from thinc.neural.util import copy_array

try:
    import cPickle as pickle
except ImportError:
    import pickle

try:
    import copy_reg
except ImportError:
    import copyreg as copy_reg

try:
    from cupy.cuda.stream import Stream as CudaStream
except ImportError:
    CudaStream = None

try:
    import cupy
except ImportError:
    cupy = None

try:
    from thinc.neural.optimizers import Optimizer
except ImportError:
    from thinc.neural.optimizers import Adam as Optimizer

pickle = pickle
copy_reg = copy_reg
CudaStream = CudaStream
cupy = cupy
copy_array = copy_array
izip = getattr(itertools, 'izip', zip)

is_windows = sys.platform.startswith('win')
is_linux = sys.platform.startswith('linux')
is_osx = sys.platform == 'darwin'

# See: https://github.com/benjaminp/six/blob/master/six.py
is_python2 = sys.version_info[0] == 2
is_python3 = sys.version_info[0] == 3
is_python_pre_3_5 = is_python2 or (is_python3 and sys.version_info[1] < 5)

if is_python2:
    bytes_ = str
    unicode_ = unicode  # noqa: F821
    basestring_ = basestring  # noqa: F821
    input_ = raw_input  # noqa: F821
    json_dumps = lambda data: ujson.dumps(data, indent=2, escape_forward_slashes=False).decode('utf8')
    path2str = lambda path: str(path).decode('utf8')

elif is_python3:
    bytes_ = bytes
    unicode_ = str
    basestring_ = str
    input_ = input
    json_dumps = lambda data: ujson.dumps(data, indent=2, escape_forward_slashes=False)
    path2str = lambda path: str(path)


def b_to_str(b_str):
    if is_python2:
        return b_str
    # important: if no encoding is set, string becomes "b'...'"
    return str(b_str, encoding='utf8')


def getattr_(obj, name, *default):
    if is_python3 and isinstance(name, bytes):
        name = name.decode('utf8')
    return getattr(obj, name, *default)


def symlink_to(orig, dest):
    if is_python2 and is_windows:
        import subprocess
        subprocess.call(['mklink', '/d', path2str(orig), path2str(dest)], shell=True)
    else:
        orig.symlink_to(dest)


def is_config(python2=None, python3=None, windows=None, linux=None, osx=None):
    return (python2 in (None, is_python2) and
            python3 in (None, is_python3) and
            windows in (None, is_windows) and
            linux in (None, is_linux) and
            osx in (None, is_osx))


def normalize_string_keys(old):
    """Given a dictionary, make sure keys are unicode strings, not bytes."""
    new = {}
    for key, value in old.items():
        if isinstance(key, bytes_):
            new[key.decode('utf8')] = value
        else:
            new[key] = value
    return new


def import_file(name, loc):
    loc = str(loc)
    if is_python_pre_3_5:
        import imp
        return imp.load_source(name, loc)
    else:
        import importlib.util
        spec = importlib.util.spec_from_file_location(name, str(loc))
        module = importlib.util.module_from_spec(spec)
        spec.loader.exec_module(module)
        return module


def locale_escape(string, errors='replace'):
    '''
    Mangle non-supported characters, for savages with ascii terminals.
    '''
    encoding = locale.getpreferredencoding()
    string = string.encode(encoding, errors).decode('utf8')
    return string
